const models = require(process.cwd());
const BorrowersFactory = require('./factories/Borrowers');
const LoansFactory = require('./factories/Loans');
const ContactsFactory = require('./factories/Contacts');

test('should have the correct schema', async () => {
  const borrower = await BorrowersFactory();
  expect(BorrowersFactory.validate(borrower.toJSON())).toBeTruthy();
});

/*
problem:
    Borrowers has a loanId key
    association config includes Loans hasMany Borrowers
*/
test.skip('should have a correct schema if Loans is included', async () => {
  const { id } = await BorrowersFactory();

  const borrower = await models.Borrowers.findOne({
    where: {
      id,
    },
    include: [
      {
          model: models.Loans,
      },
    ],
  });

  expect(BorrowersFactory.validate(borrower.toJSON())).toBeTruthy();

  const { loan } = borrower;
  expect(LoansFactory.validate(loan.toJSON())).toBeTruthy();
});

test('should have a correct schema if Contacts is included', async () => {
  const { id } = await BorrowersFactory();

  const borrower = await models.Borrowers.findOne({
    where: {
      id,
    },
    include: [
      {
          model: models.Contacts,
      },
    ],
  });

  expect(BorrowersFactory.validate(borrower.toJSON())).toBeTruthy();

  const { contact } = borrower;
  expect(ContactsFactory.validate(contact.toJSON())).toBeTruthy();
});