const models = require(process.cwd());
const ContactDocumentRequestsFactory = require('./factories/ContactDocumentRequests');
const ContactsFactory = require('./factories/Contacts');
const DocumentRequestsFactory = require('./factories/DocumentRequests');

test('should have the correct schema', async () => {
  const cdr = await ContactDocumentRequestsFactory();
  expect(ContactDocumentRequestsFactory.validate(cdr.toJSON())).toBeTruthy();
});

test('should have a correct schema if Contacts is included', async () => {
  const { id } = await ContactDocumentRequestsFactory();

  const cdr = await models.ContactDocumentRequests.findOne({
    where: {
      id,
    },
    include: [
      {
          model: models.Contacts,
      },
    ],
  });

  expect(ContactDocumentRequestsFactory.validate(cdr.toJSON())).toBeTruthy();

  const { contact } = cdr;
  expect(ContactsFactory.validate(contact.toJSON())).toBeTruthy();
});


test('should have a correct schema if DocumentRequests is included', async () => {
  const { id } = await ContactDocumentRequestsFactory();

  const cdr = await models.ContactDocumentRequests.findOne({
    where: {
      id,
    },
    include: [
      {
          model: models.DocumentRequests,
      },
    ],
  });

  expect(ContactDocumentRequestsFactory.validate(cdr.toJSON())).toBeTruthy();

  const { documentRequest } = cdr;
  expect(DocumentRequestsFactory.validate(documentRequest.toJSON())).toBeTruthy();
});