const models = require(process.cwd());
const DocumentRequestsFactory = require('./factories/DocumentRequests');
const LoansFactory = require('./factories/Loans');
const RequestedDocumentsFactory = require('./factories/RequestedDocuments');

test('should have the correct schema', async () => {
  const documentRequest = await DocumentRequestsFactory();
  expect(DocumentRequestsFactory.validate(documentRequest.toJSON())).toBeTruthy();
});

test('should have a correct schema if Loans is included', async () => {
  /*
  use case
  https://bitbucket.org/pluminc/plum.microservices.uploadeddocument-service/src/32d8da15be3dc418320bb932dcca8cc66bf9bad5/handlers/fetchUploadedDocumentsByDocumentRequestGuid.js?at=develop#fetchUploadedDocumentsByDocumentRequestGuid.js-26
  */
  const { id } = await DocumentRequestsFactory();

  const documentRequest = await models.DocumentRequests.findOne({
    where: {
      id,
    },
    include: [
      {
          model: models.Loans,
          required: false,
      },
    ],
  });

  expect(DocumentRequestsFactory.validate(documentRequest.toJSON())).toBeTruthy();

  const { loan } = documentRequest;
  expect(LoansFactory.validate(loan.toJSON())).toBeTruthy();
});

test('should have a correct schema if RequestedDocuments are included', async () => {
  const { id: documentRequestId } = await DocumentRequestsFactory();
  
  await Promise.all([
    RequestedDocumentsFactory({ documentRequestId }),
    RequestedDocumentsFactory({ documentRequestId }),
  ]);

  const documentRequest = await models.DocumentRequests.findOne({
    where: {
      id: documentRequestId,
    },
    include: [
      {
          model: models.RequestedDocuments,
      },
    ],
  });

  expect(DocumentRequestsFactory.validate(documentRequest.toJSON())).toBeTruthy();

  expect(documentRequest.requestedDocuments).toHaveLength(2);

  documentRequest.requestedDocuments.forEach((rd) => {
    expect(RequestedDocumentsFactory.validate(rd.toJSON())).toBeTruthy();
  });
});