const models = require(process.cwd());
const LenderExecutionTypesFactory = require('./factories/LenderExecutionTypes');
const LendersFactory = require('./factories/Lenders');
const ExecutionTypesFactory = require('./factories/ExecutionTypes');

test('should have the correct schema', async () => {
  const letypes = await LenderExecutionTypesFactory();
  expect(LenderExecutionTypesFactory.validate(letypes.toJSON())).toBeTruthy();
});

test('should have the correct schema if Lenders is included', async () => {
  const { id } = await LenderExecutionTypesFactory();
  const letypes = await models.LenderExecutionTypes.findOne({
    where: { id },
    include: [
      { model: models.Lenders },
    ],
  });

  expect(LenderExecutionTypesFactory.validate(letypes.toJSON())).toBeTruthy();
  expect(LendersFactory.validate(letypes.lender.toJSON())).toBeTruthy();
});

test('should have the correct schema if ExecutionTypes is included', async () => {
  const { id } = await LenderExecutionTypesFactory();
  const letypes = await models.LenderExecutionTypes.findOne({
    where: { id },
    include: [
      { model: models.ExecutionTypes },
    ],
  });

  expect(LenderExecutionTypesFactory.validate(letypes.toJSON())).toBeTruthy();
  expect(ExecutionTypesFactory.validate(letypes.executionType.toJSON())).toBeTruthy();
});