const models = require(process.cwd());
const LenderPrepaymentPenaltiesFactory = require('./factories/LenderPrepaymentPenalties');
const LendersFactory = require('./factories/Lenders');
const PrepaymentPenaltiesFactory = require('./factories/PrepaymentPenalties');

test('should have the correct schema', async () => {
  const lpp = await LenderPrepaymentPenaltiesFactory();
  expect(LenderPrepaymentPenaltiesFactory.validate(lpp.toJSON())).toBeTruthy();
});

test('should have the correct schema if Lenders is included', async () => {
  const { id } = await LenderPrepaymentPenaltiesFactory();
  const lpp = await models.LenderPrepaymentPenalties.findOne({
    where: { id },
    include: [
      { model: models.Lenders },
    ],
  });

  expect(LenderPrepaymentPenaltiesFactory.validate(lpp.toJSON())).toBeTruthy();
  expect(LendersFactory.validate(lpp.lender.toJSON())).toBeTruthy();
});

test('should have the correct schema if PrepaymentPenalties is included', async () => {
  const { id } = await LenderPrepaymentPenaltiesFactory();
  const lpp = await models.LenderPrepaymentPenalties.findOne({
    where: { id },
    include: [
      { model: models.PrepaymentPenalties },
    ],
  });

  expect(LenderPrepaymentPenaltiesFactory.validate(lpp.toJSON())).toBeTruthy();
  expect(PrepaymentPenaltiesFactory.validate(lpp.prepaymentPenalty.toJSON())).toBeTruthy();
});