const models = require(process.cwd());
const LenderPropertyTypesFactory = require('./factories/LenderPropertyTypes');
const LendersFactory = require('./factories/Lenders');
const PropertyTypesFactory = require('./factories/PropertyTypes');

test('should have the correct schema', async () => {
  const lenderPropertyType = await LenderPropertyTypesFactory();
  expect(LenderPropertyTypesFactory.validate(lenderPropertyType.toJSON())).toBeTruthy();
});


test('should have the correct schema if Lenders is included', async () => {
  const { id } = await LenderPropertyTypesFactory();
  const lenderPropertyType = await models.LenderPropertyTypes.findOne({
    where: { id },
    include: [
      { model: models.Lenders },
    ],
  });

  expect(LenderPropertyTypesFactory.validate(lenderPropertyType.toJSON())).toBeTruthy();
  expect(LendersFactory.validate(lenderPropertyType.lender.toJSON())).toBeTruthy();
});

test('should have the correct schema if PropertyTypes is included', async () => {
  const { id } = await LenderPropertyTypesFactory();
  const lenderPropertyType = await models.LenderPropertyTypes.findOne({
    where: { id },
    include: [
      { model: models.PropertyTypes },
    ],
  });

  expect(LenderPropertyTypesFactory.validate(lenderPropertyType.toJSON())).toBeTruthy();
  expect(PropertyTypesFactory.validate(lenderPropertyType.propertyType.toJSON())).toBeTruthy();
});
