const models = require(process.cwd());
const LendersFactory = require('./factories/Lenders');
const LoanOriginatorsFactory = require('./factories/LoanOriginators');
const RecoursesFactory = require('./factories/Recourses');

test('should have the correct schema', async () => {
  const lender = await LendersFactory();
  expect(LendersFactory.validate(lender.toJSON())).toBeTruthy();
});


test('should have the correct schema if LoanOriginators is included', async () => {
  const { id } = await LendersFactory();
  const lender = await models.Lenders.findOne({
    where: { id },
    include: [
      { model: models.LoanOriginators },
    ],
  });

  expect(LendersFactory.validate(lender.toJSON())).toBeTruthy();
  expect(LoanOriginatorsFactory.validate(lender.loanOriginator.toJSON())).toBeTruthy();
});

test('should have the correct schema if Recourses is included', async () => {
  const { id } = await LendersFactory();
  const lender = await models.Lenders.findOne({
    where: { id },
    include: [
      { model: models.Recourses },
    ],
  });

  expect(LendersFactory.validate(lender.toJSON())).toBeTruthy();
  expect(RecoursesFactory.validate(lender.recourse.toJSON())).toBeTruthy();
});

test('should have the correct schema if RateLocks is included', async () => {
  const { id } = await LendersFactory();
  const lender = await models.Lenders.findOne({
    where: { id },
    include: [
      { model: models.RateLocks },
    ],
  });

  expect(LendersFactory.validate(lender.toJSON())).toBeTruthy();
  expect(RecoursesFactory.validate(lender.rateLock.toJSON())).toBeTruthy();
});