const models = require(process.cwd());
const QuickSelectDocumentsFactory = require('./factories/QuickSelectDocuments');
const QuickSelectListsFactory = require('./factories/QuickSelectLists');
const ChecklistFactory = require('./factories/Checklist');

test('should have the correct schema', async () => {
  const qsd = await QuickSelectDocumentsFactory();
  expect(QuickSelectDocumentsFactory.validate(qsd.toJSON())).toBeTruthy();
});

test('should have a correct schema if QuickSelectLists is included', async () => {
  const { id } = await QuickSelectDocumentsFactory();

  const qsd = await models.QuickSelectDocuments.findOne({
    where: { id },
    include: [
      { model: models.QuickSelectLists },
    ],
  });

  expect(QuickSelectDocumentsFactory.validate(qsd.toJSON())).toBeTruthy();
  expect(QuickSelectListsFactory.validate(qsd.quickSelectList.toJSON())).toBeTruthy();
});

test('should have a correct schema if Checklist is included', async () => {
  const { id } = await QuickSelectDocumentsFactory();

  const qsd = await models.QuickSelectDocuments.findOne({
    where: { id },
    include: [
      { model: models.Checklist },
    ],
  });

  expect(QuickSelectDocumentsFactory.validate(qsd.toJSON())).toBeTruthy();
  expect(ChecklistFactory.validate(qsd.checklist.toJSON())).toBeTruthy();
});