const models = require(process.cwd());
const RequestedDocumentsFactory = require('./factories/RequestedDocuments');
const DocumentRequestsFactory = require('./factories/DocumentRequests');
const ChecklistFactory = require('./factories/Checklist');

test('should have the correct schema', async () => {
  const rd = await RequestedDocumentsFactory();
  expect(RequestedDocumentsFactory.validate(rd.toJSON())).toBeTruthy();
});

test('should have a correct schema if DocumentRequests is included', async () => {
  const { id } = await RequestedDocumentsFactory();

  const rd = await models.RequestedDocuments.findOne({
    where: { id },
    include: [
      { model: models.DocumentRequests },
    ],
  });

  expect(RequestedDocumentsFactory.validate(rd.toJSON())).toBeTruthy();
  expect(DocumentRequestsFactory.validate(rd.documentRequest.toJSON())).toBeTruthy();
});

test('should have a correct schema if Checklist is included', async () => {
  const { id } = await RequestedDocumentsFactory();

  const rd = await models.RequestedDocuments.findOne({
    where: { id },
    include: [
      { model: models.Checklist },
    ],
  });

  expect(RequestedDocumentsFactory.validate(rd.toJSON())).toBeTruthy();
  expect(ChecklistFactory.validate(rd.checklist.toJSON())).toBeTruthy();
});