const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const LoansFactory = require('./Loans');
const ContactsFactory = require('./Contacts');

const data = async (props = {}) => {
  let { contactId, loanId } = props;

  if (!contactId) {
    const contact = await ContactsFactory();
    contactId = contact.id;
  }

  if (!loanId) {
    const loan = await LoansFactory();
    loanId = loan.id;
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    contactId,
    loanId,
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  contactId: {
    type: String,
    required: true,
  },
  loanId: {
    type: String,
    required: true,
  },
  isPrimary: {
    type: Boolean,
    required: true,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.Borrowers.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);
