const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const DocumentCategoriesFactory = require('./DocumentCategories');

const data = async (props = {}) => {
  let { documentCategoryId } = props;

  if (!documentCategoryId) {
    const documentCategory = await DocumentCategoriesFactory();
    documentCategoryId = documentCategory.id;
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    category: faker.commerce.productMaterial(),
    documentCode: faker.commerce.product(),
    documentCategoryId,
    documentName: faker.commerce.productName(),
    isDeleted: false,
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  documentCategoryId: {
    type: String,
    required: true,
  },
  documentCode: {
    type: String,
    required: true,
  },
  documentName: {
    type: String,
    required: false,
  },
  isDeleted: {
    type: Boolean,
    required: false,
  },
  createdAt: {
    type: Date,
    required: true,
  },
  updatedAt: {
    type: Date,
    required: true,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.Checklist.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);
