const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const ContactsFactory = require('./Contacts');

const data = async (props = {}) => {
  let contactId;
  if (!props.contactId) {
    ({ id: contactId } = await ContactsFactory());
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    contactId,
    invitedDate: faker.date.recent(),
    lastLogin: faker.date.recent(),
    invitedByUser: faker.name.firstName(),
    signedUpDate: faker.date.recent(),
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  contactId: {
    type: String,
    required: true,
  },
  invitedDate: {
    type: Date,
    required: false,
  },
  lastLogin: {
    type: Date,
    required: false,
  },
  invitedByUser: {
    type: String,
    required: true,
  },
  signedUpDate: {
    type: Date,
    required: false,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.ContactMetadata.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);