const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const LendersFactory = require('./Lenders');
const ExecutionTypeFactory = require('./ExecutionTypes');

const data = async (props = {}) => {
  let lenderId;
  if (!props.lenderId) {
    const lender = await LendersFactory();
    lenderId = lender.id;
  }

  let executionTypeId;
  if (!props.executionTypeId) {
    const execType = await ExecutionTypeFactory();
    executionTypeId = execType.id;
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    lenderId,
    executionTypeId,
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  lenderId: {
    type: String,
    required: true,
  },
  executionTypeId: {
    type: String,
    required: true,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.LenderExecutionTypes.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);
