const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const LendersFactory = require('./Lenders');
const PrepaymentPenaltiesFactory = require('./PrepaymentPenalties');

const data = async (props = {}) => {
  let lenderId;
  if (!props.lenderId) {
    const lender = await LendersFactory();
    lenderId = lender.id;
  }

  let prepaymentPenaltyId;
  if (!props.prepaymentPenaltyId) {
    const prepaymentPenalty = await PrepaymentPenaltiesFactory();
    prepaymentPenaltyId = prepaymentPenalty.id;
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    lenderId,
    prepaymentPenaltyId,
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  lenderId: {
    type: String,
    required: true,
  },
  prepaymentPenaltyId: {
    type: String,
    required: true,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.LenderPrepaymentPenalties.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);
