const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const LendersFactory = require('./Lenders');
const PropertyTypesFactory = require('./PropertyTypes');

const data = async (props = {}) => {
  let lenderId;
  if (!props.lenderId) {
    const lender = await LendersFactory();
    lenderId = lender.id;
  }

  let propertyTypeId;
  if (!props.propertyTypeId) {
    const propertyType = await PropertyTypesFactory();
    propertyTypeId = propertyType.id;
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    lenderId,
    propertyTypeId,
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  lenderId: {
    type: String,
    required: true,
  },
  propertyTypeId: {
    type: String,
    required: false,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.LenderPropertyTypes.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);
