const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const LoanOriginatorsFactory = require('./LoanOriginators');
const RecoursesFactory = require('./Recourses');
const RateLocksFactory = require('./RateLocks');

const data = async (props = {}) => {
  let loanOriginatorId;
  if (!props.loanOriginatorId) {
    const loanOriginator = await LoanOriginatorsFactory();
    loanOriginatorId = loanOriginator.id;
  }

  let recourseId;
  if (!props.recourseId) {
    const recourse = await RecoursesFactory();
    recourseId = recourse.id;
  }

  let rateLockId;
  if (!props.rateLockId) {
    const rateLock = await RateLocksFactory();
    rateLockId = rateLock.id;
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    code: faker.random.uuid().slice(0,9),
    name: faker.name.firstName(),
    contactFirstName: faker.name.firstName(),
    contactLastName: faker.name.lastName(),
    contactPhone: faker.phone.phoneNumber(),
    contactEmail: faker.internet.email(),
    targetLoanSize: faker.lorem.word(),
    loanTerm: faker.lorem.word(),
    maximumLoanToValuePercent: 0.99,
    permanentOrBridge: faker.lorem.word(),
    ownerOccupied: true,
    singleTenant: true,
    minimumDebtYield: faker.lorem.word(),
    interestRateSpreads: faker.lorem.word(),
    lockboxCashManagement: true,
    thirdPartyConsultants: faker.commerce.productName(),
    amortization: faker.lorem.word(),
    reserves: faker.lorem.word(),
    closingCosts: faker.lorem.word(),
    fees: faker.lorem.word(),
    market: faker.lorem.word(),
    notes: faker.lorem.sentence(),
    loanOriginatorId,
    recourseId,
    rateLockId,
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  code: {
    type: String,
    required: false,
  },
  name: {
    type: String,
    required: true,
  },
  contactFirstName: {
    type: String,
    required: false,
  },
  contactLastName: {
    type: String,
    required: false,
  },
  contactPhone: {
    type: String,
    required: false,
  },
  contactEmail: {
    type: String,
    required: false,
  },
  loanOriginatorId: {
    type: String,
    required: false,
  },
  targetLoanSize: {
    type: String,
    required: false,
  },
  loanTerm: {
    type: String,
    required: false,
  },
  maximumLoanToValuePercent: {
    type: Number,
    required: false,
  },
  permanentOrBridge: {
    type: String,
    required: false,
  },
  ownerOccupied: {
    type: Boolean,
    required: false,
  },
  singleTenant: {
    type: Boolean,
    required: false,
  },
  minimumDebtYield: {
    type: String,
    required: false,
  },
  recourseId: {
    type: String,
    required: false,
  },
  interestRateSpreads: {
    type: String,
    required: false,
  },
  lockboxCashManagement: {
    type: Boolean,
    required: false,
  },
  rateLockId: {
    type: String,
    required: false,
  },
  thirdPartyConsultants: {
    type: String,
    required: false,
  },
  amortization: {
    type: String,
    required: false,
  },
  reserves: {
    type: String,
    required: false,
  },
  closingCosts: {
    type: String,
    required: false,
  },
  market: {
    type: String,
    required: false,
  },
  fees: {
    type: String,
    required: false,
  },
  notes: {
    type: String,
    required: false,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.Lenders.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);
