const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const LoansFactory = require('./Loans');
const DocumentRequestsFactory = require('./DocumentRequests');

const data = async (props = {}) => {
  let loanId;
  if (!props.loanId) {
    ({ id: loanId } = await LoansFactory());
  }

  let documentRequestId;
  if (!props.documentRequestId) {
    ({ id: documentRequestId } = await DocumentRequestsFactory());
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    loanId,
    documentRequestId,
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  loanId: {
    type: String,
    required: true,
  },
  documentRequestId: {
    type: String,
    required: true,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.LoanDocumentRequests.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);