const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const data = async (props = {}) => {
  const defaultProps = {
    externalGuid: faker.random.uuid(),
    loanAmount: 123124534543543,
    status: faker.hacker.adjective(),
    applicationReceiptDate: faker.date.recent(),
    targetFundingDate: faker.date.future(),
    propertyType: faker.commerce.productName(),
    isPendingDeletion: faker.date.future(),
    loanPurpose: faker.commerce.productAdjective(),
    ownerOccupancy: faker.lorem.word().slice(0,9),
    executionType: faker.company.catchPhrase().slice(0,9),
    multiFamilyUnitRange: faker.lorem.word().slice(0,9),
    originator: faker.name.firstName(),
    loanType:  faker.company.catchPhrase().slice(0,19),
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  propertyDetailId: {
    type: String,
    required: false,
  },
  loanAmount: {
    type: String,
    required: false,
  },
  status: {
    type: String,
    required: false,
  },
  applicationReceiptDate: {
    type: Date,
    required: false,
  },
  targetFundingDate: {
    type: Date,
    required: false,
  },
  propertyType: {
    type: String,
    required: false,
  },
  createdAt: {
    type: Date,
    required: true,
  },
  updatedAt: {
    type: Date,
    required: true,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
  isPendingDeletion: {
    type: Date,
    required: false,
  },
  loanPurpose: {
    type: String,
    required: false,
  },
  ownerOccupancy: {
    type: String,
    required: false,
  },
  executionType: {
    type: String,
    required: false,
  },
  multiFamilyUnitRange: {
    type: String,
    required: false,
  },
  originator: {
    type: String,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.Loans.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);