const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const data = async (props = {}) => {
  const defaultProps = {
    externalGuid: faker.random.uuid(),
    name: faker.address.streetName(),
    address: faker.address.streetAddress(),
    streetAddress: faker.address.streetAddress(),
    city: faker.address.city(),
    state: faker.address.state(),
    zipCode: faker.address.zipCode(),
    country: faker.address.country(),
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  name: {
    type: String,
    required: false,
  },
  address: {
    type: String,
    required: false,
  },
  streetAddress: {
    type: String,
    required: false,
  },
  city: {
    type: String,
    required: false,
  },
  state: {
    type: String,
    required: false,
  },
  zipCode: {
    type: String,
    required: false,
  },
  country: {
    type: String,
    required: false,
  },
  createdAt: {
    type: Date,
    required: false, // this should be true but the model says allowNull
  },
  updatedAt: {
    type: Date,
    required: false, // this should be true but the model says allowNull
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.PropertyDetails.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);
