const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const data = async (props = {}) => {
  const defaultProps = {
    externalGuid: faker.random.uuid(),
    fullName: `${faker.name.firstName()} ${faker.name.lastName()}`,
    email: faker.internet.email(),
    plannedPurhaseDate: faker.date.future(),
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  fullName: {
    type: String,
    required: true,
  },
  email: {
    type: String,
    required: true,
  },
  plannedPurhaseDate: {
    type: Date,
    required: false,
  },
  createdAt: {
    type: Date,
    required: false, // this should be true but the model says allowNull
  },
  updatedAt: {
    type: Date,
    required: false, // this should be true but the model says allowNull
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.ProspectInformation.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);
