const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const QuickSelectListsFactory = require('./QuickSelectLists');
const ChecklistFactory = require('./Checklist');

const data = async (props = {}) => {
  let quickSelectId;
  if (!props.quickSelectId) {
    ({ id: quickSelectId } = await QuickSelectListsFactory());
  }

  let checklistId;
  if (!props.checklistId) {
    ({ id: checklistId } = await ChecklistFactory());
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    quickSelectId,
    checklistId,
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  quickSelectId: {
    type: String,
    required: true,
  },
  checklistId: {
    type: String,
    required: true,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.QuickSelectDocuments.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);