const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const DocumentRequestsFactory = require('./DocumentRequests');
const ChecklistFactory = require('./Checklist');

const data = async (props = {}) => {
  let documentRequestId;
  if (!props.documentRequestId) {
    ({ id: documentRequestId } = await DocumentRequestsFactory());
  }

  let checklistId;
  if (!props.checklistId) {
    ({ id: checklistId } = await ChecklistFactory());
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    documentRequestId,
    checklistId,
    status: faker.commerce.productAdjective(),
    approvedOn: faker.date.past(),
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  documentRequestId: {
    type: String,
    required: true,
  },
  checklistId: {
    type: String,
    required: true,
  },
  status: {
    type: String,
    required: true,
  },
  approvedOn: {
    type: Date,
    required: false,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.RequestedDocuments.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);