const faker = require('faker');
const validate = require('validate');
const models = require(process.cwd());

const RequestedDocumentsFactory = require('./RequestedDocuments');

const data = async (props = {}) => {
  let requestedDocumentId;
  if (!props.requestedDocumentId) {
    ({ id: requestedDocumentId } = await RequestedDocumentsFactory());
  }

  const defaultProps = {
    externalGuid: faker.random.uuid(),
    requestedDocumentId,
    originalname: faker.commerce.productName(),
    encoding: faker.database.type(),
    mimetype: faker.database.engine(),
    destination: faker.address.country(),
    filename: faker.company.companyName(),
    path: faker.internet.url(),
    size: 12312312312312,
    uploadedBy: faker.name.lastName(),
  };

  return {
    ...defaultProps,
    ...props,
  }
};

const schema = new validate({
  id: {
    type: String,
    required: true,
  },
  externalGuid: {
    type: String,
    required: true,
  },
  requestedDocumentId: {
    type: String,
    required: true,
  },
  originalName: {
    type: String,
    required: false,
  },
  encoding: {
    type: String,
    required: false,
  },
  mimetype: {
    type: String,
    required: false,
  },
  destination: {
    type: String,
    required: false,
  },
  filename: {
    type: String,
    required: false,
  },
  path: {
    type: String,
    required: false,
  },
  size: {
    type: String,
    required: false,
  },
  createdAt: {
    type: Date,
    required: false,
  },
  updatedAt: {
    type: Date,
    required: false,
  },
  deletedAt: {
    type: Date,
    required: false,
  },
});

module.exports = async (props = {}) => {
  return models.UploadedDocuments.create(await data(props));
}

module.exports.validate = (instance) => schema.validate(instance);