-- The release-changeset contains all the ALTER commands required on the tables etc.
-- This should also contain any system data/records or lookup values that needs to be inserted everytime.

--NOTE
--append the alter commands and data that needs to be always there to the bottom of file. Like alter commands or system data.
--make sure to do exist checks since this script will run continuously after every commit
USE [DocumentDb]
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

/*DP-31*/

IF NOT EXISTS(SELECT TOP 1 1 FROM sys.columns WHERE object_id = OBJECT_ID('dbo.Loans') and name='ApplicationReceiptDate')
BEGIN
	ALTER TABLE dbo.Loans
	ADD ApplicationReceiptDate DATETIME2(7)
END

GO

IF NOT EXISTS(SELECT TOP 1 1 FROM sys.columns WHERE object_id = OBJECT_ID('dbo.Loans') and name='TargetFundingDate')
BEGIN
	ALTER TABLE dbo.Loans
	ADD TargetFundingDate DATETIME2(7)
END

/*END DP-31*/

/* Adding Loan Statuses */

UPDATE [dbo].[LoanStatuses]
SET
    [Display] = N'New Lead'
    ,[Value] = N'newlead'
WHERE [ExternalGuid] = CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000001')
IF @@ROWCOUNT=0
BEGIN
    INSERT INTO [dbo].[LoanStatuses] (
                [ExternalGuid]
                ,[Display]
                ,[Value]
            )
        VALUES
            (
                CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000001')
                ,N'New Lead'
                ,N'newlead'
            )
END
GO

UPDATE [dbo].[LoanStatuses]
SET
    [Display] = N'New Deal'
    ,[Value] = N'newdeal'
WHERE [ExternalGuid] = CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000010')
IF @@ROWCOUNT=0
BEGIN
    INSERT INTO [dbo].[LoanStatuses] (
                [ExternalGuid]
                ,[Display]
                ,[Value]
            )
        VALUES
            (
                CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000010')
                ,N'New Deal'
                ,N'newdeal'
            )
END
GO
UPDATE [dbo].[LoanStatuses]
SET
    [Display] = N'Signed Up'
    ,[Value] = N'signedup'
WHERE [ExternalGuid] = CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000100')
IF @@ROWCOUNT=0
BEGIN
    INSERT INTO [dbo].[LoanStatuses] (
                [ExternalGuid]
                ,[Display]
                ,[Value]
            )
        VALUES
            (
                CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000100')
                ,N'Signed Up'
                ,N'signedup'
            )
END
GO
UPDATE [dbo].[LoanStatuses]
SET
    [Display] = N'Closed'
    ,[Value] = N'Closed'
WHERE [ExternalGuid] = CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000001000')
IF @@ROWCOUNT=0
BEGIN
    INSERT INTO [dbo].[LoanStatuses] (
                [ExternalGuid]
                ,[Display]
                ,[Value]
            )
        VALUES
            (
                CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000001000')
                ,N'Closed'
                ,N'closed'
            )
END
GO
UPDATE [dbo].[LoanStatuses]
SET
    [Display] = N'Dead'
    ,[Value] = N'dead'
WHERE [ExternalGuid] = CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000010000')
IF @@ROWCOUNT=0
BEGIN
    INSERT INTO [dbo].[LoanStatuses] (
                [ExternalGuid]
                ,[Display]
                ,[Value]
            )
        VALUES
            (
                CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000010000')
                ,N'Dead'
                ,N'dead'
            )
END
GO

/* Adding Document Statuses */
UPDATE [dbo].[DocumentStatuses]
SET
    [Display] = N'Requested'
    ,[Value] = N'requested'
WHERE [ExternalGuid] = CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000001')
IF @@ROWCOUNT=0
BEGIN
    INSERT INTO [dbo].[DocumentStatuses] (
                [ExternalGuid]
                ,[Display]
                ,[Value]
            )
        VALUES
            (
                CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000001')
                ,N'Requested'
                ,N'requested'
            )
END
GO
UPDATE [dbo].[DocumentStatuses]
SET
    [Display] = N'Uploaded'
    ,[Value] = N'uploaded'
WHERE [ExternalGuid] = CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000010')
IF @@ROWCOUNT=0
BEGIN
    INSERT INTO [dbo].[DocumentStatuses] (
                [ExternalGuid]
                ,[Display]
                ,[Value]
            )
        VALUES
            (
                CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000010')
                ,N'Uploaded'
                ,N'uploaded'
            )
END
GO
UPDATE [dbo].[DocumentStatuses]
SET
    [Display] = N'Under Review'
    ,[Value] = N'underreview'
WHERE [ExternalGuid] = CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000100')
IF @@ROWCOUNT=0
BEGIN
    INSERT INTO [dbo].[DocumentStatuses] (
                [ExternalGuid]
                ,[Display]
                ,[Value]
            )
        VALUES
            (
                CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000000100')
                ,N'Under Review'
                ,N'underreview'
            )
END
GO
UPDATE [dbo].[DocumentStatuses]
SET
    [Display] = N'Satisfactory'
    ,[Value] = N'satisfactory'
WHERE [ExternalGuid] = CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000001000')
IF @@ROWCOUNT=0
BEGIN
    INSERT INTO [dbo].[DocumentStatuses] (
                [ExternalGuid]
                ,[Display]
                ,[Value]
            )
        VALUES
            (
                CONVERT(uniqueidentifier,N'00000000-0000-0000-0000-000000001000')
                ,N'Satisfactory'
                ,N'satisfactory'
            )
END
GO

-- Adding additional fields for the PropertyDetails
IF COL_LENGTH('[dbo].[PropertyDetails]','StreetAddress') IS NULL
	AND COL_LENGTH('[dbo].[PropertyDetails]','City') IS NULL
	AND COL_LENGTH('[dbo].[PropertyDetails]','[State]') IS NULL
	AND COL_LENGTH('[dbo].[PropertyDetails]','ZipCode') IS NULL
	AND COL_LENGTH('[dbo].[PropertyDetails]','Country') IS NULL
	ALTER TABLE dbo.PropertyDetails
	  ADD StreetAddress NVARCHAR(150),
	  City NVARCHAR(50),
	  [State] NVARCHAR(50),
	  ZipCode NVARCHAR(10),
	  Country NVARCHAR(50);

GO

/* Add Unique Constraint for ExternaGuids */

--Borrower
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_Borrowers_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[Borrowers]
	ADD CONSTRAINT UQ_Borrowers_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--Checklist
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_Checklist_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[Checklist]
	ADD CONSTRAINT UQ_Checklist_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--Comments
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_Comments_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[Comments]
	ADD CONSTRAINT UQ_Comments_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--Contacts
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_Contacts_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[Contacts]
	ADD CONSTRAINT UQ_Contacts_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--DocumentCategories
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_DocumentCategories_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[DocumentCategories]
	ADD CONSTRAINT UQ_DocumentCategories_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--DocumentRequests
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_DocumentRequests_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[DocumentRequests]
	ADD CONSTRAINT UQ_DocumentRequests_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--DocumentStatuses
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_DocumentStatuses_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[DocumentStatuses]
	ADD CONSTRAINT UQ_DocumentStatuses_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--Loans
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_Loans_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[Loans]
	ADD CONSTRAINT UQ_Loans_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--LoanStatuses
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_LoanStatuses_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[LoanStatuses]
	ADD CONSTRAINT UQ_LoanStatuses_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--PropertyDetails
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_PropertyDetails_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[PropertyDetails]
	ADD CONSTRAINT UQ_PropertyDetails_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--QuickSelectDocuments
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_QuickSelectDocuments_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[QuickSelectDocuments]
	ADD CONSTRAINT UQ_QuickSelectDocuments_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--QuickSelectLists
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_QuickSelectLists_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[QuickSelectLists]
	ADD CONSTRAINT UQ_QuickSelectLists_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_QuickSelectLists_Name'
	)
BEGIN
	ALTER TABLE [dbo].[QuickSelectLists]
	ADD CONSTRAINT UQ_QuickSelectLists_Name UNIQUE ([Name]); 
END
GO

--RequestedDocuments
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_RequestedDocuments_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[RequestedDocuments]
	ADD CONSTRAINT UQ_RequestedDocuments_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

--UploadedDocuments
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_UploadedDocuments_ExternalGuid'
	)
BEGIN
	ALTER TABLE [dbo].[UploadedDocuments]
	ADD CONSTRAINT UQ_UploadedDocuments_ExternalGuid UNIQUE (ExternalGuid); 
END
GO

/* END Add Unique Constraint for ExternaGuids */

/* Add Unique Constraint for Id Combinations */

--Borrowers
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_Borrowers_ContactId_LoanId'
	)
BEGIN
	ALTER TABLE [dbo].[Borrowers]
	ADD CONSTRAINT UQ_Borrowers_ContactId_LoanId UNIQUE (ContactId, LoanId); 
END
GO

--QuickSelectDocuments
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_QuickSelectDocuments_QuickSelectId_ChecklistId'
	)
BEGIN
	ALTER TABLE [dbo].[QuickSelectDocuments]
	ADD CONSTRAINT UQ_QuickSelectDocuments_QuickSelectId_ChecklistId UNIQUE (QuickSelectId, ChecklistId); 
END
GO

--RequestedDocuments
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_RequestedDocuments_ChecklistId_DocumentRequestId'
	)
BEGIN
	ALTER TABLE [dbo].[RequestedDocuments]
	ADD CONSTRAINT UQ_RequestedDocuments_ChecklistId_DocumentRequestId UNIQUE (ChecklistId, DocumentRequestId); 
END
GO


/* END Add Unique Constraint for Id Combinations */

/* Add Unique Constraint for Email Addess */

--Contacts
IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_Contacts_PrimaryEmail'
	)
BEGIN
	ALTER TABLE [dbo].[Contacts]
	ADD CONSTRAINT UQ_Contacts_PrimaryEmail UNIQUE (PrimaryEmail); 
END
GO

/* END Add Unique Constraint for Email Addess */

/*
	Purpose of having soft delete for Requested Documents
	Add DeleteAt Column , datetime2 as data type and can be null
*/
IF COL_LENGTH('RequestedDocuments', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE RequestedDocuments ADD DeletedAt datetime2(7) NULL;
END

/*END Add DeleteAt Column , datetime2 as data type and can be null */

/*
    Contacts DeletedAt column.
*/
IF COL_LENGTH('Contacts', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE Contacts ADD DeletedAt datetime2(7) NULL;
END


/*
    QuickSelectLists DeletedAt column.
*/
IF COL_LENGTH('QuickSelectLists', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE QuickSelectLists ADD DeletedAt datetime2(7) NULL;
END
/*
    End QuickSelectLists DeletedAt column.
*/


/* 
    Create DefaultQuickSelectList Table
*/

IF OBJECT_ID('DefaultQuickSelectList') IS NULL
BEGIN
	SET ANSI_NULLS ON
	SET QUOTED_IDENTIFIER ON

	CREATE TABLE [dbo].[DefaultQuickSelectList](
		[Id] [bigint] IDENTITY(1,1) NOT NULL,
		[ExternalGuid] [uniqueidentifier] NOT NULL,
		[PropertyType] [nvarchar](150) NOT NULL,
		[QuickSelectListId] [bigint] NULL,
		[CreatedAt] [datetime2](7) NULL,
		[UpdatedAt] [datetime2](7) NULL,
		[DeletedAt] [datetime2](7) NULL,
	 CONSTRAINT [PK_DefaultQuickSelectList] PRIMARY KEY CLUSTERED 
	(
		[Id] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY],
	 CONSTRAINT [UQ_DefaultQuickSelectList_ExternalGuid] UNIQUE NONCLUSTERED 
	(
		[ExternalGuid] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY],
	 CONSTRAINT [UQ_DefaultQuickSelectList_PropertyType] UNIQUE NONCLUSTERED 
	(
		[PropertyType] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	ALTER TABLE [dbo].[DefaultQuickSelectList] ADD  CONSTRAINT [DF_DefaultQuickSelectList_ExternalGuid]  DEFAULT (newid()) FOR [ExternalGuid]


	ALTER TABLE [dbo].[DefaultQuickSelectList] ADD  CONSTRAINT [DF_DefaultQuickSelectList_CreatedAt]  DEFAULT (getutcdate()) FOR [CreatedAt]

	ALTER TABLE [dbo].[DefaultQuickSelectList] ADD  CONSTRAINT [DF_DefaultQuickSelectList_UpdatedAt]  DEFAULT (getutcdate()) FOR [UpdatedAt]

	ALTER TABLE [dbo].[DefaultQuickSelectList]  WITH CHECK ADD  CONSTRAINT [FK_DefaultQuickSelectList_QuickSelectList] FOREIGN KEY([QuickSelectListId])
	REFERENCES [dbo].[QuickSelectLists] ([Id])

	ALTER TABLE [dbo].[DefaultQuickSelectList] CHECK CONSTRAINT [FK_DefaultQuickSelectList_QuickSelectList]

END

/* 
    END Create DefaultQuickSelectList Table
*/


/*DP-311*/

IF NOT EXISTS(SELECT TOP 1 1 FROM sys.columns WHERE object_id = OBJECT_ID('dbo.Loans') and name='PropertyType')
BEGIN
	ALTER TABLE dbo.Loans
	ADD PropertyType nvarchar(150) NULL
END

GO
/*END DP-311*/



/*
	Purpose of having soft delete for Loans
	Add DeleteAt Column , datetime2 as data type and can be null
*/
IF COL_LENGTH('Loans', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE Loans ADD DeletedAt datetime2(7) NULL;
END
GO
/*END Add DeleteAt Column , datetime2 as data type and can be null */

/*	
	Add IsPendingDeletion Column as datetime2.
*/

IF COL_LENGTH('Loans', 'IsPendingDeletion') IS NULL
BEGIN
        ALTER TABLE Loans ADD IsPendingDeletion datetime2  NULL;		
END

/*END Add IsPendingDeletion Column as datetime2. */


/*
	add LoanPurpose
*/
IF COL_LENGTH('Loans', 'LoanPurpose') IS NULL
    BEGIN
        ALTER TABLE Loans ADD LoanPurpose varchar(20) NULL;
END

/*
	add OwnerOccupancy
*/
IF COL_LENGTH('Loans', 'OwnerOccupancy') IS NULL
    BEGIN
        ALTER TABLE Loans ADD OwnerOccupancy varchar(10) NULL;
END

/*
	add ExecutionType
*/

IF COL_LENGTH('Loans', 'ExecutionType') IS NULL
    BEGIN
        ALTER TABLE Loans ADD ExecutionType varchar(30) NULL;
END

/*	
	Drop SubCategory Column in DocumentCategories
*/

IF COL_LENGTH('[dbo].[DocumentCategories]', 'SubCategory') IS NOT NULL
BEGIN
        ALTER TABLE [dbo].[DocumentCategories] DROP COLUMN [SubCategory];		
END

/*END Drop SubCategory Column in DocumentCategories */


/* Add Unique Constraint on Category column in DocumentCategories table */

IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_DocumentCategories_Category'
	)
BEGIN
	ALTER TABLE [dbo].[DocumentCategories]
	ADD CONSTRAINT UQ_DocumentCategories_Category UNIQUE (Category); 
END
GO

/* END Add Unique Constraint on Category column in DocumentCategories table */

/* Add Unique Constraint on DocumentName column in Checklist table */

IF NOT EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='UQ_Checklist_DocumentName'
	)
BEGIN
	ALTER TABLE [dbo].[Checklist]
	ADD CONSTRAINT UQ_Checklist_DocumentName UNIQUE (DocumentName); 
END
GO

/* END Add Unique Constraint on DocumentName column in Checklist table */

/*
******************************************************************************************
******************************************************************************************
*****************      NEW CHECKLIST AND QUICKSELECT (M&M RELEASE)       *****************
******************************************************************************************
******************************************************************************************
*/


/*
	Add Document Categories:
		Property
		Owner
		3rd Party Reports
		Legal/Closing
*/

DECLARE @CATEGORY_PROPERTY NVARCHAR(150) = 'Property';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[DocumentCategories] WHERE [Category]=@CATEGORY_PROPERTY)
BEGIN
	INSERT INTO[dbo].[DocumentCategories]([ExternalGuid], [Category])
	VALUES(NEWID(), @CATEGORY_PROPERTY);
END
GO

DECLARE @CATEGORY_OWNER NVARCHAR(150) = 'Owner';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[DocumentCategories] WHERE [Category]=@CATEGORY_OWNER)
BEGIN
	INSERT INTO[dbo].[DocumentCategories]([ExternalGuid], [Category])
	VALUES(NEWID(), @CATEGORY_OWNER);
END
GO

DECLARE @CATEGORY_3RDPARTYREPORTS NVARCHAR(150) = '3rd Party Reports';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[DocumentCategories] WHERE [Category]=@CATEGORY_3RDPARTYREPORTS)
BEGIN
	INSERT INTO[dbo].[DocumentCategories]([ExternalGuid], [Category])
	VALUES(NEWID(), @CATEGORY_3RDPARTYREPORTS);
END
GO

DECLARE @CATEGORY_LEGALORCLOSING NVARCHAR(150) = 'Legal/Closing';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[DocumentCategories] WHERE [Category]=@CATEGORY_LEGALORCLOSING)
BEGIN
	INSERT INTO[dbo].[DocumentCategories]([ExternalGuid], [Category])
	VALUES(NEWID(), @CATEGORY_LEGALORCLOSING);
END
GO

/*
	END OF
	Add Document Categories:
		Property
		Owner
		3rd Party Reports
		Legal/Closing
*/


/*
	Add Checklist for 3rd Party Reports:
		ALTA Survey
		Title Insurance
		Appraisal
		Property Condition Report 
		Environmental Site Assessment
		Seismic/PML report
		Zoning Report
*/
DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='3rd Party Reports');
DECLARE @DocumentName NVARCHAR(150) = 'ALTA Survey';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='3rd Party Reports');
DECLARE @DocumentName NVARCHAR(150) = 'Title Insurance';
IF NOT EXISTS (SELECT TOP 1 1 From [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='3rd Party Reports');
DECLARE @DocumentName NVARCHAR(150) = 'Appraisal';
IF NOT EXISTS (SELECT TOP 1 1 From [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='3rd Party Reports');
DECLARE @DocumentName NVARCHAR(150) = 'Property Condition Report';
IF NOT EXISTS (SELECT TOP 1 1 From [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='3rd Party Reports');
DECLARE @DocumentName NVARCHAR(150) = 'Environmental Site Assessment';
IF NOT EXISTS (SELECT TOP 1 1 From [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='3rd Party Reports');
DECLARE @DocumentName NVARCHAR(150) = 'Seismic/PML report';
IF NOT EXISTS (SELECT TOP 1 1 From [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='3rd Party Reports');
DECLARE @DocumentName NVARCHAR(150) = 'Zoning Report';
IF NOT EXISTS (SELECT TOP 1 1 From [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO
/*
	END OF
	Add Checklist for 3rd Party Reports:
		ALTA Survey
		Title Insurance
		Appraisal
		Property Condition Report 
		Environmental Site Assessment
		Seismic/PML report
		Zoning Report
*/


/*
	Add Checklist for Legal/Closing:
		Accounts Payable Ledger
		Tenant Estoppels & SNDA's for Commercial Leases
		List of Service Contracts
		Copy of Service Contracts for Term (1 year or more) Contracts
		Property Tax Bills- 3 years
		Insurance Bills
		Bank statements for Property- trailing 12 months
		Current Payroll Register
		CAM Bills
		Current Aged Receivables Report
		Current Real Estate Tax Bill
		Poperty Management Agreement & Amendments
		Property Management Company Resume & Bio
		Final Loan & Escrow Settlement Statements
		Certificate of Occupancy
		List of FF&E for Property
		Form Residential Lease Agreement
		List of Top Corporate Accounts 
		5-Year Capex Budget
		PACE Report
		Copy of all Union Contracts
		Product Improvement Program (PIP)
		Comfort Letter
		Copy of Liquor License/other business licenses
*/

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Accounts Payable Ledger';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Tenant Estoppels & SNDA''s for Commercial Leases';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'List of Service Contracts';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Copy of Service Contracts for Term (1 year or more) Contracts';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Property Tax Bills- 3 years';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Insurance Bills';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Bank statements for Property- trailing 12 months';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Current Payroll Register';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'CAM Bills';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Current Aged Receivables Report';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Current Real Estate Tax Bill';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Poperty Management Agreement & Amendments';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Property Management Company Resume & Bio';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Final Loan & Escrow Settlement Statements';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Certificate of Occupancy';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'List of FF&E for Property';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Form Residential Lease Agreement';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'List of Top Corporate Accounts ';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
	INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = '5-Year Capex Budget';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
	INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'PACE Report';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
	INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Copy of all Union Contracts';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
	INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Product Improvement Program (PIP)';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
	INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Comfort Letter';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
	INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Legal/Closing');
DECLARE @DocumentName NVARCHAR(150) = 'Copy of Liquor License/other business licenses';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
	INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO
/*
	END OF
	Add Checklist for Legal/Closing:
		Accounts Payable Ledger
		Tenant Estoppels & SNDA's for Commercial Leases
		List of Service Contracts
		Copy of Service Contracts for Term (1 year or more) Contracts
		Property Tax Bills- 3 years
		Insurance Bills
		Bank statements for Property- trailing 12 months
		Current Payroll Register
		CAM Bills
		Current Aged Receivables Report
		Current Real Estate Tax Bill
		Poperty Management Agreement & Amendments
		Property Management Company Resume & Bio
		Final Loan & Escrow Settlement Statements
		Certificate of Occupancy
		List of FF&E for Property
		Form Residential Lease Agreement
		List of Top Corporate Accounts 
		5-Year Capex Budget
		PACE Report
		Copy of all Union Contracts
		Product Improvement Program (PIP)
		Comfort Letter
		Copy of Liquor License/other business licenses
*/



/*
	Add Checklist for Owner:
		Entity Formation Documents for Borrower
		Entity Formation Documents for Managing Member/ GP
		Entity Formation Documents for Key Principal- Entity
		List of Owners & Ownerships Intersts/ Org Chart
		Updated Certificate of Good Standing
		Authorization to Conduct Business in Subject State
		Federal Tax Returns for Borrowing Entity
		Federal Tax Returns for Managing Member/ GP
		Federal Tax Returns for Key Principal(s)
		Current Financial Statements for Managing Member/ GP
		Current FInancial Statements for Key Principal(s)
		Real Estate Owned Schedule for Borrowing Entity
		Real Estate Owned Schedule for Managing Member/ GP
		Real Estate Owned Schedule for Key Principal(s)
		Credit Forms for Borrowing Entity
		Credit Forms for Managing Member/ GP
		Credit Forms for Key Principal(s)
		Payoff Letter
		Contact Lender/ Credit References
		Verification of Liquidity
		Resume/Bio of Managing Member/ GP
		Resume/Bio of Key Principal(s)
*/

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Entity Formation Documents for Borrower';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Entity Formation Documents for Managing Member/ GP';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Entity Formation Documents for Key Principal- Entity';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'List of Owners & Ownerships Intersts/ Org Chart';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Updated Certificate of Good Standing';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Authorization to Conduct Business in Subject State';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Federal Tax Returns for Borrowing Entity';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Federal Tax Returns for Managing Member/ GP';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Federal Tax Returns for Key Principal(s)';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Current Financial Statements for Managing Member/ GP';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Current FInancial Statements for Key Principal(s)';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Real Estate Owned Schedule for Borrowing Entity';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Real Estate Owned Schedule for Managing Member/ GP';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Real Estate Owned Schedule for Key Principal(s)';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Credit Forms for Borrowing Entity';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Credit Forms for Managing Member/ GP';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Credit Forms for Key Principal(s)';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Payoff Letter';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Contact Lender/ Credit References';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Verification of Liquidity';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Resume/Bio of Managing Member/ GP';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Owner');
DECLARE @DocumentName NVARCHAR(150) = 'Resume/Bio of Key Principal(s)';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

/*
	END OF
	Add Checklist for Owner:		
		Entity Formation Documents for Borrower
		Entity Formation Documents for Managing Member/ GP
		Entity Formation Documents for Key Principal- Entity
		List of Owners & Ownerships Intersts/ Org Chart
		Updated Certificate of Good Standing
		Authorization to Conduct Business in Subject State
		Federal Tax Returns for Borrowing Entity
		Federal Tax Returns for Managing Member/ GP
		Federal Tax Returns for Key Principal(s)
		Current Financial Statements for Managing Member/ GP
		Current FInancial Statements for Key Principal(s)
		Real Estate Owned Schedule for Borrowing Entity
		Real Estate Owned Schedule for Managing Member/ GP
		Real Estate Owned Schedule for Key Principal(s)
		Credit Forms for Borrowing Entity
		Credit Forms for Managing Member/ GP
		Credit Forms for Key Principal(s)
		Payoff Letter
		Contact Lender/ Credit References
		Verification of Liquidity
		Resume/Bio of Managing Member/ GP
		Resume/Bio of Key Principal(s)
*/

/*
	Add Checklist for Property:
		Trailing 12 Month Profit & Loss Statement	
		Previous 3 calendar years Profit & Loss Statement
		Current Year Budget or Pro Forma
		Cost Basis
		Current Rent Roll
		3 Years of Occupancy History
		Commercial Leases & Amendments
		Major Tenant Financials
		Tenant Sales
		Utility Bills-trailing 12 months
		Purchase & Sale Agreement (PSA)
		Sources & Uses
		Offering Memorandum
		Latest Market Survey of Competitive Properties
		Most recent STR Report and Year End for past 3 years
		List of new supply
		Executed Franchise Agreement

*/

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Trailing 12 Month Profit & Loss Statement';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Previous 3 calendar years Profit & Loss Statement';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Current Year Budget or Pro Forma';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Cost Basis';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Current Rent Roll';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = '3 Years of Occupancy History';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Commercial Leases & Amendments';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Major Tenant Financials';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Tenant Sales';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Utility Bills-trailing 12 months';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Purchase & Sale Agreement (PSA)';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Sources & Uses';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Offering Memorandum';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Latest Market Survey of Competitive Properties';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Most recent STR Report and Year End for past 3 years';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'List of new supply';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

DECLARE @CategoryId BIGINT = (SELECT Id FROM [dbo].[DocumentCategories] WHERE [Category]='Property');
DECLARE @DocumentName NVARCHAR(150) = 'Executed Franchise Agreement';
IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[Checklist] WHERE DocumentName=@DocumentName)
BEGIN
INSERT INTO [dbo].[Checklist](ExternalGuid, DocumentCategoryId, DocumentCode, DocumentName)
	VALUES(NEWID(), @CategoryId, '', @DocumentName);
END
GO

/*
	END OF
	Add Checklist for Property:
		Trailing 12 Month Profit & Loss Statement	
		Previous 3 calendar years Profit & Loss Statement
		Current Year Budget or Pro Forma
		Cost Basis
		Current Rent Roll
		3 Years of Occupancy History
		Commercial Leases & Amendments
		Major Tenant Financials
		Tenant Sales
		Utility Bills-trailing 12 months
		Purchase & Sale Agreement (PSA)
		Sources & Uses
		Offering Memorandum
		Latest Market Survey of Competitive Properties
		Most recent STR Report and Year End for past 3 years
		List of new supply
		Executed Franchise Agreement

*/


/* QuickSelectList: Pre-termsheet Checklist for Hotel */

DECLARE @Name NVARCHAR(150) = 'Pre-termsheet Checklist for Hotel';
DECLARE @Description NVARCHAR(500) = 'Pre-termsheet Checklist for Hotel';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-termsheet Checklist for Hotel */

/* QuickSelectList: Pre-termsheet Checklist for Self-Storage */

DECLARE @Name NVARCHAR(150) = 'Pre-termsheet Checklist for Self-Storage';
DECLARE @Description NVARCHAR(500) = 'Pre-termsheet Checklist for Self-Storage';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-termsheet Checklist for Self-Storage */


/* QuickSelectList: Pre-termsheet Checklist of Industrial */

DECLARE @Name NVARCHAR(150) = 'Pre-termsheet Checklist of Industrial';
DECLARE @Description NVARCHAR(500) = 'Pre-termsheet Checklist of Industrial';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-termsheet Checklist of Industrial */


/* QuickSelectList: Pre-termsheet Checklist of Retail */

DECLARE @Name NVARCHAR(150) = 'Pre-termsheet Checklist of Retail';
DECLARE @Description NVARCHAR(500) = 'Pre-termsheet Checklist of Retail';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-termsheet Checklist of Retail */


/* QuickSelectList: Pre-termsheet Checklist of Office */

DECLARE @Name NVARCHAR(150) = 'Pre-termsheet Checklist of Office';
DECLARE @Description NVARCHAR(500) = 'Pre-termsheet Checklist of Office';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-termsheet Checklist of Office */


/* QuickSelectList: Pre-termsheet Checklist of Multifamily */

DECLARE @Name NVARCHAR(150) = 'Pre-termsheet Checklist of Multifamily';
DECLARE @Description NVARCHAR(500) = 'Pre-termsheet Checklist of Multifamily';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-termsheet Checklist of Multifamily */


/* QuickSelectList: Pre-termsheet Checklist of Mobile Home Park */

DECLARE @Name NVARCHAR(150) = 'Pre-termsheet Checklist of Mobile Home Park';
DECLARE @Description NVARCHAR(500) = 'Pre-termsheet Checklist of Mobile Home Park';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-termsheet Checklist of Mobile Home Park */


/* QuickSelectList: Pre-application Checklist for Hotel (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist for Hotel (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist for Hotel (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist for Hotel (Balance Sheet) */


/* QuickSelectList: Pre-application Checklist for Self-Storage (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist for Self-Storage (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist for Self-Storage (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist for Self-Storage (Balance Sheet) */


/* QuickSelectList: Pre-application Checklist of Industrial (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Industrial (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Industrial (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Industrial (Balance Sheet) */


/* QuickSelectList: Pre-application Checklist of Retail (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Retail (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Retail (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Retail (Balance Sheet) */


/* QuickSelectList: Pre-application Checklist of Office (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Office (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Office (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Office (Balance Sheet) */


/* QuickSelectList: Pre-application Checklist of Multifamily (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Multifamily (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Multifamily (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Multifamily (Balance Sheet) */


/* QuickSelectList: Pre-application Checklist of Mobile Home Park (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Mobile Home Park (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Mobile Home Park (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Mobile Home Park (Balance Sheet) */


/* QuickSelectList: Pre-application Checklist for Hotel (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist for Hotel (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist for Hotel (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist for Hotel (CMBS) */


/* QuickSelectList: Pre-application Checklist for Self-Storage (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist for Self-Storage (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist for Self-Storage (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist for Self-Storage (CMBS) */


/* QuickSelectList: Pre-application Checklist of Industrial (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Industrial (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Industrial (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Industrial (CMBS) */


/* QuickSelectList: Pre-application Checklist of Retail (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Retail (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Retail (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Retail (CMBS) */


/* QuickSelectList: Pre-application Checklist of Office (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Office (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Office (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Office (CMBS) */


/* QuickSelectList: Pre-application Checklist of Multifamily (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Multifamily (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Multifamily (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Multifamily (CMBS) */


/* QuickSelectList: Pre-application Checklist of Mobile Home Park (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Pre-application Checklist of Mobile Home Park (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Pre-application Checklist of Mobile Home Park (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Pre-application Checklist of Mobile Home Park (CMBS) */


/* QuickSelectList: Legal/Closing Checklist for Hotel (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist for Hotel (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist for Hotel (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist for Hotel (Balance Sheet) */


/* QuickSelectList: Legal/Closing Checklist for Self-Storage (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist for Self-Storage (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist for Self-Storage (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist for Self-Storage (Balance Sheet) */


/* QuickSelectList: Legal/Closing Checklist of Industrial (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Industrial (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklistfor Industrial (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Industrial (Balance Sheet) */


/* QuickSelectList: Legal/Closing Checklist of Retail (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Retail (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist of Retail (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Retail (Balance Sheet) */


/* QuickSelectList: Legal/Closing Checklist of Office (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Office (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist of Office (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Office (Balance Sheet) */


/* QuickSelectList: Legal/Closing Checklist of Multifamily (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Multifamily (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist of Multifamily (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Multifamily (Balance Sheet) */


/* QuickSelectList: Legal/Closing Checklist of Mobile Home Park (Balance Sheet) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Mobile Home Park (Balance Sheet)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist of Mobile Home Park (Balance Sheet)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Mobile Home Park (Balance Sheet) */


/* QuickSelectList: Legal/Closing Checklist for Hotel (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist for Hotel (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist for Hotel (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist for Hotel (CMBS) */


/* QuickSelectList: Legal/Closing Checklist for Self-Storage (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist for Self-Storage (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist for Self-Storage (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist for Self-Storage (CMBS) */


/* QuickSelectList: Legal/Closing Checklist of Industrial (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Industrial (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist of Industrial (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Industrial (CMBS) */


/* QuickSelectList: Legal/Closing Checklist of Retail (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Retail (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist of Retail (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Retail (CMBS) */


/* QuickSelectList: Legal/Closing Checklist of Office (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Office (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist of Office (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Office (CMBS) */


/* QuickSelectList: Legal/Closing Checklist of Multifamily (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Multifamily (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist of Multifamily (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Multifamily (CMBS) */


/* QuickSelectList: Legal/Closing Checklist of Mobile Home Park (CMBS) */

DECLARE @Name NVARCHAR(150) = 'Legal/Closing Checklist of Mobile Home Park (CMBS)';
DECLARE @Description NVARCHAR(500) = 'Legal/Closing Checklist of Mobile Home Park (CMBS)';

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Name)
BEGIN
	INSERT INTO [dbo].[QuickSelectLists](ExternalGuid, [Name], [Description], CreatedAt)
	VALUES (NEWID(), @Name, @Description, GETUTCDATE());
END

GO

/* END QuickSelectList: Legal/Closing Checklist of Mobile Home Park (CMBS) */





/* Initial List for Pre-termsheet Checklist for Hotel */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist for Hotel');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Trailing 12 Month Profit & Loss Statement'
		,'Previous 3 calendar years Profit & Loss Statement'
		,'Current Year Budget or Pro Forma'
		,'Offering Memorandum'
		,'Most recent STR Report and Year End for past 3 years'

	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-termsheet Checklist for Hotel */

/* Initial List for Pre-termsheet Checklist for Self-Storage */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist for Self-Storage');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Trailing 12 Month Profit & Loss Statement'
		,'Previous 3 calendar years Profit & Loss Statement'
		,'Current Year Budget or Pro Forma'
		,'Current Rent Roll'
		,'Offering Memorandum'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-termsheet Checklist for Self-Storage */

/* Initial List for Pre-termsheet Checklist of Industrial */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Industrial');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Trailing 12 Month Profit & Loss Statement'
		,'Previous 3 calendar years Profit & Loss Statement'
		,'Current Year Budget or Pro Forma'
		,'Current Rent Roll'
		,'Offering Memorandum'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-termsheet Checklist of Industrial */

/* Initial List for Pre-termsheet Checklist of Retail */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Retail');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Trailing 12 Month Profit & Loss Statement'
		,'Previous 3 calendar years Profit & Loss Statement'
		,'Current Year Budget or Pro Forma'
		,'Current Rent Roll'
		,'Offering Memorandum'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-termsheet Checklist of Retail */


/* Initial List for Pre-termsheet Checklist of Office */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Office');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Trailing 12 Month Profit & Loss Statement'
		,'Previous 3 calendar years Profit & Loss Statement'
		,'Current Year Budget or Pro Forma'
		,'Current Rent Roll'
		,'Offering Memorandum'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-termsheet Checklist of Office */


/* Initial List for Pre-termsheet Checklist of Multifamily */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Multifamily');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Trailing 12 Month Profit & Loss Statement'
		,'Previous 3 calendar years Profit & Loss Statement'
		,'Current Year Budget or Pro Forma'
		,'Current Rent Roll'
		,'Offering Memorandum'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-termsheet Checklist of Multifamily */


/* Initial List for Pre-termsheet Checklist of Mobile Home Park */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Mobile Home Park');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Trailing 12 Month Profit & Loss Statement'
		,'Previous 3 calendar years Profit & Loss Statement'
		,'Current Year Budget or Pro Forma'
		,'Current Rent Roll'
		,'Offering Memorandum'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-termsheet Checklist of Mobile Home Park */


/* Initial List for Pre-application Checklist for Hotel (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist for Hotel (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
		,'Executed Franchise Agreement'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist for Hotel (Balance Sheet) */


/* Initial List for Pre-application Checklist for Self-Storage (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist for Self-Storage (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist for Self-Storage (Balance Sheet) */


/* Initial List for Pre-application Checklist of Industrial (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Industrial (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Industrial (Balance Sheet) */


/* Initial List for Pre-application Checklist of Retail (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Retail (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Retail (Balance Sheet) */


/* Initial List for Pre-application Checklist of Office (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Office (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Office (Balance Sheet) */


/* Initial List for Pre-application Checklist of Multifamily (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Multifamily (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Multifamily (Balance Sheet) */


/* Initial List for Pre-application Checklist of Mobile Home Park (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Mobile Home Park (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Mobile Home Park (Balance Sheet) */


/* Initial List for Pre-application Checklist for Hotel (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist for Hotel (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
		,'Executed Franchise Agreement'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist for Hotel (CMBS) */


/* Initial List for Pre-application Checklist for Self-Storage (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist for Self-Storage (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist for Self-Storage (CMBS) */


/* Initial List for Pre-application Checklist of Industrial (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Industrial (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Industrial (CMBS) */


/* Initial List for Pre-application Checklist of Retail (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Retail (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Retail (CMBS) */


/* Initial List for Pre-application Checklist of Office (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Office (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Office (CMBS) */


/* Initial List for Pre-application Checklist of Multifamily (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Multifamily (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Multifamily (CMBS) */


/* Initial List for Pre-application Checklist of Mobile Home Park (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-application Checklist of Mobile Home Park (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Cost Basis'
		,'3 Years of Occupancy History'
		,'Purchase & Sale Agreement (PSA)'
		,'Sources & Uses'
		,'Current Financial Statements for Managing Member/ GP'
		,'Current FInancial Statements for Key Principal(s)'
		,'Real Estate Owned Schedule for Borrowing Entity'
		,'Real Estate Owned Schedule for Managing Member/ GP'
		,'Real Estate Owned Schedule for Key Principal(s)'
		,'Resume/Bio of Managing Member/ GP'
		,'Resume/Bio of Key Principal(s)'
		,'Latest Market Survey of Competitive Properties'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Pre-application Checklist of Mobile Home Park (CMBS) */


/* Initial List for Legal/Closing Checklist for Hotel (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist for Hotel (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
		,'5-Year Capex Budget'
		,'List of new supply'
		,'PACE Report'
		,'Product Improvement Program (PIP)'
		,'Comfort Letter'
		,'Copy of Liquor License/other business licenses'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist for Hotel (Balance Sheet) */


/* Initial List for Legal/Closing Checklist for Self-Storage (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist for Self-Storage (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist for Self-Storage (Balance Sheet) */


/* Initial List for Legal/Closing Checklist of Industrial (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Industrial (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Commercial Leases & Amendments'
		,'Major Tenant Financials'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Industrial (Balance Sheet) */


/* Initial List for Legal/Closing Checklist of Retail (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Retail (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Commercial Leases & Amendments'
		,'Major Tenant Financials'
		,'Tenant Sales'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Retail (Balance Sheet) */


/* Initial List for Legal/Closing Checklist of Office (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Office (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Commercial Leases & Amendments'
		,'Major Tenant Financials'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Office (Balance Sheet) */


/* Initial List for Legal/Closing Checklist of Multifamily (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Multifamily (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Commercial Leases & Amendments'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
		,'Form Residential Lease Agreement'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Multifamily (Balance Sheet) */


/* Initial List for Legal/Closing Checklist of Mobile Home Park (Balance Sheet) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Mobile Home Park (Balance Sheet)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Commercial Leases & Amendments'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
		,'Form Residential Lease Agreement'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Mobile Home Park (Balance Sheet) */


/* Initial List for Legal/Closing Checklist for Hotel (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist for Hotel (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Accounts Payable Ledger'
		,'List of Service Contracts'
		,'Copy of Service Contracts for Term (1 year or more) Contracts'
		,'Utility Bills-trailing 12 months'
		,'Property Tax Bills- 3 years'
		,'Insurance Bills'
		,'Bank statements for Property- trailing 12 months'
		,'Current Payroll Register'
		,'CAM Bills'
		,'Current Aged Receivables Report'
		,'Current Real Estate Tax Bill'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'List of FF&E for Property'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Authorization to Conduct Business in Subject State'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Contact Lender/ Credit References'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
		,'List of Top Corporate Accounts '
		,'5-Year Capex Budget'
		,'List of new supply'
		,'PACE Report'
		,'Copy of all Union Contracts'
		,'Product Improvement Program (PIP)'
		,'Comfort Letter'
		,'Copy of Liquor License/other business licenses'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist for Hotel (CMBS) */


/* Initial List for Legal/Closing Checklist for Self-Storage (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist for Self-Storage (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Accounts Payable Ledger'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'List of Service Contracts'
		,'Copy of Service Contracts for Term (1 year or more) Contracts'
		,'Utility Bills-trailing 12 months'
		,'Property Tax Bills- 3 years'
		,'Insurance Bills'
		,'Bank statements for Property- trailing 12 months'
		,'Current Payroll Register'
		,'CAM Bills'
		,'Current Aged Receivables Report'
		,'Current Real Estate Tax Bill'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'List of FF&E for Property'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Authorization to Conduct Business in Subject State'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Contact Lender/ Credit References'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist for Self-Storage (CMBS) */


/* Initial List for Legal/Closing Checklist of Industrial (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Industrial (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Accounts Payable Ledger'
		,'Commercial Leases & Amendments'
		,'Major Tenant Financials'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'List of Service Contracts'
		,'Copy of Service Contracts for Term (1 year or more) Contracts'
		,'Utility Bills-trailing 12 months'
		,'Property Tax Bills- 3 years'
		,'Insurance Bills'
		,'Bank statements for Property- trailing 12 months'
		,'Current Payroll Register'
		,'CAM Bills'
		,'Current Aged Receivables Report'
		,'Current Real Estate Tax Bill'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'List of FF&E for Property'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Authorization to Conduct Business in Subject State'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Contact Lender/ Credit References'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Industrial (CMBS) */


/* Initial List for Legal/Closing Checklist of Retail (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Retail (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Accounts Payable Ledger'
		,'Commercial Leases & Amendments'
		,'Major Tenant Financials'
		,'Tenant Sales'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'List of Service Contracts'
		,'Copy of Service Contracts for Term (1 year or more) Contracts'
		,'Utility Bills-trailing 12 months'
		,'Property Tax Bills- 3 years'
		,'Insurance Bills'
		,'Bank statements for Property- trailing 12 months'
		,'Current Payroll Register'
		,'CAM Bills'
		,'Current Aged Receivables Report'
		,'Current Real Estate Tax Bill'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'List of FF&E for Property'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Authorization to Conduct Business in Subject State'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Contact Lender/ Credit References'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Retail (CMBS) */


/* Initial List for Legal/Closing Checklist of Office (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Office (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Accounts Payable Ledger'
		,'Commercial Leases & Amendments'
		,'Major Tenant Financials'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'List of Service Contracts'
		,'Copy of Service Contracts for Term (1 year or more) Contracts'
		,'Utility Bills-trailing 12 months'
		,'Property Tax Bills- 3 years'
		,'Insurance Bills'
		,'Bank statements for Property- trailing 12 months'
		,'Current Payroll Register'
		,'CAM Bills'
		,'Current Aged Receivables Report'
		,'Current Real Estate Tax Bill'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'List of FF&E for Property'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Authorization to Conduct Business in Subject State'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Contact Lender/ Credit References'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Office (CMBS) */


/* Initial List for Legal/Closing Checklist of Multifamily (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Multifamily (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Accounts Payable Ledger'
		,'Commercial Leases & Amendments'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'List of Service Contracts'
		,'Copy of Service Contracts for Term (1 year or more) Contracts'
		,'Utility Bills-trailing 12 months'
		,'Property Tax Bills- 3 years'
		,'Insurance Bills'
		,'Bank statements for Property- trailing 12 months'
		,'Current Payroll Register'
		,'CAM Bills'
		,'Current Aged Receivables Report'
		,'Current Real Estate Tax Bill'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'List of FF&E for Property'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Authorization to Conduct Business in Subject State'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Contact Lender/ Credit References'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
		,'Form Residential Lease Agreement'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Multifamily (CMBS) */


/* Initial List for Legal/Closing Checklist of Mobile Home Park (CMBS) */
DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Legal/Closing Checklist of Mobile Home Park (CMBS)');

MERGE [dbo].[QuickSelectDocuments] AS T
USING 
(
	SELECT Id FROM Checklist
	WHERE DocumentName IN 
	(
		'Accounts Payable Ledger'
		,'Commercial Leases & Amendments'
		,'Tenant Estoppels & SNDA''s for Commercial Leases'
		,'List of Service Contracts'
		,'Copy of Service Contracts for Term (1 year or more) Contracts'
		,'Utility Bills-trailing 12 months'
		,'Property Tax Bills- 3 years'
		,'Insurance Bills'
		,'Bank statements for Property- trailing 12 months'
		,'Current Payroll Register'
		,'CAM Bills'
		,'Current Aged Receivables Report'
		,'Current Real Estate Tax Bill'
		,'Poperty Management Agreement & Amendments'
		,'Property Management Company Resume & Bio'
		,'Final Loan & Escrow Settlement Statements'
		,'ALTA Survey'
		,'Certificate of Occupancy'
		,'List of FF&E for Property'
		,'Title Insurance'
		,'Entity Formation Documents for Borrower'
		,'Entity Formation Documents for Managing Member/ GP'
		,'Entity Formation Documents for Key Principal- Entity'
		,'List of Owners & Ownerships Intersts/ Org Chart'
		,'List of Owners & Ownership Interests/ Org Chart'
		,'Updated Certificate of Good Standing'
		,'Authorization to Conduct Business in Subject State'
		,'Federal Tax Returns for Borrowing Entity'
		,'Federal Tax Returns for Managing Member/ GP'
		,'Federal Tax Returns for Key Principal(s)'
		,'Credit Forms for Borrowing Entity'
		,'Credit Forms for Managing Member/ GP'
		,'Credit Forms for Key Principal(s)'
		,'Payoff Letter'
		,'Contact Lender/ Credit References'
		,'Verification of Liquidity'
		,'Appraisal'
		,'Property Condition Report '
		,'Environmental Site Assessment'
		,'Seismic/PML report'
		,'Zoning Report'
		,'Form Residential Lease Agreement'
	)) AS S
ON (T.QuickSelectId = @QuickSelectListId 
	AND  T.CheckListId = S.Id)
WHEN NOT MATCHED BY TARGET 
	THEN 
	INSERT(ExternalGuid, QuickSelectId, ChecklistId) 
	VALUES(NEWID(), @QuickSelectListId, S.Id)
WHEN NOT MATCHED BY SOURCE AND T.QuickSelectId = @QuickSelectListId 
    THEN DELETE;

GO
/* END Initial List for Legal/Closing Checklist of Mobile Home Park (CMBS) */




/*
	Insert Default Quick Select List per Property Type for:
		Pre-termsheet Checklist for Hotel
		Pre-termsheet Checklist for Self-Storage
		Pre-termsheet Checklist of Industrial
		Pre-termsheet Checklist of Retail
		Pre-termsheet Checklist of Office
		Pre-termsheet Checklist of Multifamily
		Pre-termsheet Checklist of Mobile Home Park
*/

DECLARE @QuickSelectListId_Retail BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Retail');
DECLARE @QuickSelectListId_Office BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Office');
DECLARE @QuickSelectListId_Industrial BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Industrial');
DECLARE @QuickSelectListId_Multifamily BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Multifamily');
DECLARE @QuickSelectListId_MobileHomePark BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist of Mobile Home Park');
DECLARE @QuickSelectListId_SelfStorage BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist for Self-Storage');
DECLARE @QuickSelectListId_Hotel BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]='Pre-termsheet Checklist for Hotel');

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[DefaultQuickSelectList] WHERE PropertyType='retail')
BEGIN
	INSERT INTO [dbo].[DefaultQuickSelectList] (ExternalGuid, PropertyType, QuickSelectListId)
	SELECT NEWID(), 'retail', @QuickSelectListId_Retail
END

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[DefaultQuickSelectList] WHERE PropertyType='office')
BEGIN
	INSERT INTO [dbo].[DefaultQuickSelectList] (ExternalGuid, PropertyType, QuickSelectListId)
	SELECT NEWID(), 'office', @QuickSelectListId_Office
END

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[DefaultQuickSelectList] WHERE PropertyType='industrial')
BEGIN
	INSERT INTO [dbo].[DefaultQuickSelectList] (ExternalGuid, PropertyType, QuickSelectListId)
	SELECT NEWID(), 'industrial', @QuickSelectListId_Industrial
END

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[DefaultQuickSelectList] WHERE PropertyType='multifamily')
BEGIN
	INSERT INTO [dbo].[DefaultQuickSelectList] (ExternalGuid, PropertyType, QuickSelectListId)
	SELECT NEWID(), 'multifamily', @QuickSelectListId_Multifamily
END

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[DefaultQuickSelectList] WHERE PropertyType='mobilehomepark')
BEGIN
	INSERT INTO [dbo].[DefaultQuickSelectList] (ExternalGuid, PropertyType, QuickSelectListId)
	SELECT NEWID(), 'mobilehomepark', @QuickSelectListId_MobileHomePark
END

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[DefaultQuickSelectList] WHERE PropertyType='selfstorage')
BEGIN
	INSERT INTO [dbo].[DefaultQuickSelectList] (ExternalGuid, PropertyType, QuickSelectListId)
	SELECT NEWID(), 'selfstorage', @QuickSelectListId_SelfStorage
END

IF NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[DefaultQuickSelectList] WHERE PropertyType='hotel')
BEGIN
	INSERT INTO [dbo].[DefaultQuickSelectList] (ExternalGuid, PropertyType, QuickSelectListId)
	SELECT NEWID(), 'hotel', @QuickSelectListId_Hotel
END

GO
/*
	END Insert Default Quick Select List per Property Type for:
		Pre-termsheet Checklist for Hotel
		Pre-termsheet Checklist for Self-Storage
		Pre-termsheet Checklist of Industrial
		Pre-termsheet Checklist of Retail
		Pre-termsheet Checklist of Office
		Pre-termsheet Checklist of Multifamily
		Pre-termsheet Checklist of Mobile Home Park
*/



/*
******************************************************************************************
******************************************************************************************
*****************   END OF NEW CHECKLIST AND QUICKSELECT (M&M RELEASE)   *****************
******************************************************************************************
******************************************************************************************
*/




/*
	Start of Release Changeset for Milky way
*/


/* DP-589 Quickselects should use consistent title. 
    Use "for" instead of "of" for the following checklist:

    Pre-termsheet Checklist of Industrial
    Pre-termsheet Checklist of Retail
    Pre-termsheet Checklist of Office
    Pre-termsheet Checklist of Multifamily
    Pre-termsheet Checklist of Mobile Home Park

    Pre-application Checklist of Industrial (Balance Sheet)
    Pre-application Checklist of Retail (Balance Sheet)
    Pre-application Checklist of Office (Balance Sheet)
    Pre-application Checklist of Multifamily (Balance Sheet)
    Pre-application Checklist of Mobile Home Park (Balance Sheet)

    Pre-application Checklist of Industrial (CMBS)
    Pre-application Checklist of Retail (CMBS)
    Pre-application Checklist of Office (CMBS)
    Pre-application Checklist of Multifamily (CMBS)
    Pre-application Checklist of Mobile Home Park (CMBS)

    Legal/Closing Checklist of Industrial (Balance Sheet)
    Legal/Closing Checklist of Retail (Balance Sheet)
    Legal/Closing Checklist of Office (Balance Sheet)
    Legal/Closing Checklist of Multifamily (Balance Sheet)
    Legal/Closing Checklist of Mobile Home Park (Balance Sheet)

    Legal/Closing Checklist of Industrial (CMBS)
    Legal/Closing Checklist of Retail (CMBS)
    Legal/Closing Checklist of Office (CMBS)
    Legal/Closing Checklist of Multifamily (CMBS)
    Legal/Closing Checklist of Mobile Home Park (CMBS)

*/

DECLARE @Old_Name NVARCHAR(150) = 'Pre-termsheet Checklist of Industrial';
DECLARE @New_Name NVARCHAR(500) = 'Pre-termsheet Checklist for Industrial';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-termsheet Checklist of Retail';
DECLARE @New_Name NVARCHAR(500) = 'Pre-termsheet Checklist for Retail';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-termsheet Checklist of Office';
DECLARE @New_Name NVARCHAR(500) = 'Pre-termsheet Checklist for Office';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-termsheet Checklist of Multifamily';
DECLARE @New_Name NVARCHAR(500) = 'Pre-termsheet Checklist for Multifamily';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-termsheet Checklist of Mobile Home Park';
DECLARE @New_Name NVARCHAR(500) = 'Pre-termsheet Checklist for Mobile Home Park';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO


DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Industrial (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Industrial (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Retail (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Retail (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Office (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Office (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Multifamily (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Multifamily (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Mobile Home Park (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Mobile Home Park (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO


DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Industrial (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Industrial (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Retail (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Retail (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Office (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Office (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Multifamily (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Multifamily (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Pre-application Checklist of Mobile Home Park (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Pre-application Checklist for Mobile Home Park (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO


DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Industrial (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Industrial (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Retail (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Retail (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Office (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Office (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Multifamily (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Multifamily (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Mobile Home Park (Balance Sheet)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Mobile Home Park (Balance Sheet)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO


DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Industrial (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Industrial (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Retail (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Retail (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Office (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Office (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Multifamily (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Multifamily (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

DECLARE @Old_Name NVARCHAR(150) = 'Legal/Closing Checklist of Mobile Home Park (CMBS)';
DECLARE @New_Name NVARCHAR(500) = 'Legal/Closing Checklist for Mobile Home Park (CMBS)';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@Old_Name)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[QuickSelectLists] WHERE [Name]=@New_Name)
BEGIN
    UPDATE [dbo].[QuickSelectLists] SET [Name] = @New_Name ,[Description] = @New_Name
    WHERE [Name] = @Old_Name
END

GO

/* END DP-589 Quickselects should use consistent title. 

    Use "for" instead of "of" for the following checklist:

    Pre-termsheet Checklist of Industrial
    Pre-termsheet Checklist of Retail
    Pre-termsheet Checklist of Office
    Pre-termsheet Checklist of Multifamily
    Pre-termsheet Checklist of Mobile Home Park

    Pre-application Checklist of Industrial (Balance Sheet)
    Pre-application Checklist of Retail (Balance Sheet)
    Pre-application Checklist of Office (Balance Sheet)
    Pre-application Checklist of Multifamily (Balance Sheet)
    Pre-application Checklist of Mobile Home Park (Balance Sheet)

    Pre-application Checklist of Industrial (CMBS)
    Pre-application Checklist of Retail (CMBS)
    Pre-application Checklist of Office (CMBS)
    Pre-application Checklist of Multifamily (CMBS)
    Pre-application Checklist of Mobile Home Park (CMBS)

    Legal/Closing Checklist of Industrial (Balance Sheet)
    Legal/Closing Checklist of Retail (Balance Sheet)
    Legal/Closing Checklist of Office (Balance Sheet)
    Legal/Closing Checklist of Multifamily (Balance Sheet)
    Legal/Closing Checklist of Mobile Home Park (Balance Sheet)

    Legal/Closing Checklist of Industrial (CMBS)
    Legal/Closing Checklist of Retail (CMBS)
    Legal/Closing Checklist of Office (CMBS)
    Legal/Closing Checklist of Multifamily (CMBS)
    Legal/Closing Checklist of Mobile Home Park (CMBS)
*/

/*
DP-590
*/

DECLARE @Old_DocName NVARCHAR(150) = 'List of Owners & Ownerships Intersts/ Org Chart';
DECLARE @New_DocName NVARCHAR(500) = 'List of Owners & Ownership Interests/ Org Chart';

IF EXISTS (SELECT TOP 1 1 FROM [dbo].[CheckList] WHERE [DocumentName]=@Old_DocName)
AND NOT EXISTS (SELECT TOP 1 1 FROM [dbo].[CheckList] WHERE [DocumentName]=@New_DocName)
BEGIN
    UPDATE [dbo].[CheckList] set [DocumentName] = @New_DocName
        WHERE [DocumentName] = @Old_DocName
END

GO

/* 
	DP-670 Duplicate records in QuickSelectList and Checklist when changeset.sql is executed twice or more. 
*/

DECLARE @QuickSelectListName NVARCHAR(150);  

DECLARE QuickSelectLists_cursor CURSOR FOR   

SELECT  'Pre-termsheet Checklist of Industrial'
UNION ALL SELECT  'Pre-termsheet Checklist of Retail'
UNION ALL SELECT  'Pre-termsheet Checklist of Office'
UNION ALL SELECT  'Pre-termsheet Checklist of Multifamily'
UNION ALL SELECT  'Pre-termsheet Checklist of Mobile Home Park'
UNION ALL SELECT  'Pre-application Checklist of Industrial (Balance Sheet)'
UNION ALL SELECT  'Pre-application Checklist of Retail (Balance Sheet)'
UNION ALL SELECT  'Pre-application Checklist of Office (Balance Sheet)'
UNION ALL SELECT  'Pre-application Checklist of Multifamily (Balance Sheet)'
UNION ALL SELECT  'Pre-application Checklist of Mobile Home Park (Balance Sheet)'
UNION ALL SELECT  'Pre-application Checklist of Industrial (CMBS)'
UNION ALL SELECT  'Pre-application Checklist of Retail (CMBS)'
UNION ALL SELECT  'Pre-application Checklist of Office (CMBS)'
UNION ALL SELECT  'Pre-application Checklist of Multifamily (CMBS)'
UNION ALL SELECT  'Pre-application Checklist of Mobile Home Park (CMBS)'
UNION ALL SELECT  'Legal/Closing Checklist of Industrial (Balance Sheet)'
UNION ALL SELECT  'Legal/Closing Checklist of Retail (Balance Sheet)'
UNION ALL SELECT  'Legal/Closing Checklist of Office (Balance Sheet)'
UNION ALL SELECT  'Legal/Closing Checklist of Multifamily (Balance Sheet)'
UNION ALL SELECT  'Legal/Closing Checklist of Mobile Home Park (Balance Sheet)'
UNION ALL SELECT  'Legal/Closing Checklist of Industrial (CMBS)'
UNION ALL SELECT  'Legal/Closing Checklist of Retail (CMBS)'
UNION ALL SELECT  'Legal/Closing Checklist of Office (CMBS)'
UNION ALL SELECT  'Legal/Closing Checklist of Multifamily (CMBS)'
UNION ALL SELECT 'Legal/Closing Checklist of Mobile Home Park (CMBS)';

OPEN QuickSelectLists_cursor  

FETCH NEXT FROM QuickSelectLists_cursor   
INTO @QuickSelectListName

WHILE @@FETCH_STATUS = 0  
BEGIN

	DECLARE @QuickSelectListId BIGINT = (SELECT Id FROM QuickSelectLists WHERE [Name]=@QuickSelectListName);
  
	IF @QuickSelectListId IS NOT NULL
	BEGIN
		DELETE FROM [dbo].[QuickSelectDocuments] WHERE QuickSelectId = @QuickSelectListId;
		DELETE FROM [dbo].[QuickSelectLists] WHERE Id = @QuickSelectListId;
	END	
    FETCH NEXT FROM QuickSelectLists_cursor   
	INTO @QuickSelectListName
END   
CLOSE QuickSelectLists_cursor;  
DEALLOCATE QuickSelectLists_cursor;  

GO

DECLARE @Old_DocName NVARCHAR(150) = 'List of Owners & Ownerships Intersts/ Org Chart';
DECLARE @ChecklistId BIGINT = (SELECT Id FROM Checklist WHERE DocumentName = @Old_DocName);

IF @ChecklistId IS NOT NULL
BEGIN
	DELETE FROM [dbo].[QuickSelectDocuments] WHERE ChecklistId = @ChecklistId;
	DELETE FROM [dbo].[CheckList] WHERE Id = @ChecklistId;
END	

GO

/*
END DP-670 Duplicate records in QuickSelectList and Checklist when changeset.sql is executed twice or more.
*/

/*
	End of Release Changeset for Milky way
*/

/*
	Start of Release Changeset for Starburst
*/

USE DocumentDb
GO

/*
	DP-622: Add new column IsDefaultChecklist. This will determine system defined quickselectlists.
*/

IF COL_LENGTH('[dbo].[QuickSelectLists]','IsDefaultChecklist') IS NULL
BEGIN
	ALTER TABLE [dbo].[QuickSelectLists]
	ADD IsDefaultChecklist BIT NULL	  
END
GO

/*
	END DP-622: Add new column IsDefaultChecklist. This will determine system defined quickselectlists.
*/

/*
	DP-622: Set column IsDefaultChecklist as true for all system defined quickselectlists.
*/

UPDATE [dbo].[QuickSelectLists]
SET	IsDefaultChecklist = 1
WHERE [Name] IN
	('Legal/Closing Checklist for Hotel (Balance Sheet)'
	,'Legal/Closing Checklist for Hotel (CMBS)'
	,'Legal/Closing Checklist for Industrial (Balance Sheet)'
	,'Legal/Closing Checklist for Industrial (CMBS)'
	,'Legal/Closing Checklist for Mobile Home Park (Balance Sheet)'
	,'Legal/Closing Checklist for Mobile Home Park (CMBS)'
	,'Legal/Closing Checklist for Multifamily (Balance Sheet)'
	,'Legal/Closing Checklist for Multifamily (CMBS)'
	,'Legal/Closing Checklist for Office (Balance Sheet)'
	,'Legal/Closing Checklist for Office (CMBS)'
	,'Legal/Closing Checklist for Retail (Balance Sheet)'
	,'Legal/Closing Checklist for Retail (CMBS)'
	,'Legal/Closing Checklist for Self-Storage (Balance Sheet)'
	,'Legal/Closing Checklist for Self-Storage (CMBS)'
	,'Pre-application Checklist for Hotel (Balance Sheet)'
	,'Pre-application Checklist for Hotel (CMBS)'
	,'Pre-application Checklist for Industrial (Balance Sheet)'
	,'Pre-application Checklist for Industrial (CMBS)'
	,'Pre-application Checklist for Mobile Home Park (Balance Sheet)'
	,'Pre-application Checklist for Mobile Home Park (CMBS)'
	,'Pre-application Checklist for Multifamily (Balance Sheet)'
	,'Pre-application Checklist for Multifamily (CMBS)'
	,'Pre-application Checklist for Office (Balance Sheet)'
	,'Pre-application Checklist for Office (CMBS)'
	,'Pre-application Checklist for Retail (Balance Sheet)'
	,'Pre-application Checklist for Retail (CMBS)'
	,'Pre-application Checklist for Self-Storage (Balance Sheet)'
	,'Pre-application Checklist for Self-Storage (CMBS)'
	,'Pre-termsheet Checklist for Hotel'
	,'Pre-termsheet Checklist for Industrial'
	,'Pre-termsheet Checklist for Mobile Home Park'
	,'Pre-termsheet Checklist for Multifamily'
	,'Pre-termsheet Checklist for Office'
	,'Pre-termsheet Checklist for Retail'
	,'Pre-termsheet Checklist for Self-Storage')
GO
/*
	END DP-622: Set column IsDefaultChecklist as true for all system defined quickselectlists.
*/


/*
    Checklist DeletedAt column.
*/
IF COL_LENGTH('Checklist', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE Checklist ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End Checklist DeletedAt column.
*/

/*
    Borrowers DeletedAt column.
*/
IF COL_LENGTH('Borrowers', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE Borrowers ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End Borrowers DeletedAt column.
*/

/*
    Comments DeletedAt column.
*/
IF COL_LENGTH('Comments', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE Comments ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End Comments DeletedAt column.
*/

/*
    DocumentCategories DeletedAt column.
*/
IF COL_LENGTH('DocumentCategories', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE DocumentCategories ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End DocumentCategories DeletedAt column.
*/

/*
    DocumentRequests DeletedAt column.
*/
IF COL_LENGTH('DocumentRequests', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE DocumentRequests ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End DocumentRequests DeletedAt column.
*/

/*
    DocumentStatuses DeletedAt column.
*/
IF COL_LENGTH('DocumentStatuses', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE DocumentStatuses ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End DocumentStatuses DeletedAt column.
*/

/*
    LoanStatuses DeletedAt column.
*/
IF COL_LENGTH('LoanStatuses', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE LoanStatuses ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End LoanStatuses DeletedAt column.
*/

/*
    PropertyDetails DeletedAt column.
*/
IF COL_LENGTH('PropertyDetails', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE PropertyDetails ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End PropertyDetails DeletedAt column.
*/

/*
    QuickSelectDocuments DeletedAt column.
*/
IF COL_LENGTH('QuickSelectDocuments', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE QuickSelectDocuments ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End QuickSelectDocuments DeletedAt column.
*/

/*
    UploadedDocuments DeletedAt column.
*/
IF COL_LENGTH('UploadedDocuments', 'DeletedAt') IS NULL
    BEGIN
        ALTER TABLE UploadedDocuments ADD DeletedAt datetime2(7) NULL;
END
GO
/*
    End UploadedDocuments DeletedAt column.
*/

/*
	The End of Release Changeset for Starburst
*/

/***************
	 Release Changeset for Gushers
***************/

/* 
	Create [dbo].[ContactMetadata] 
*/

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

IF (NOT EXISTS (SELECT TOP 1 1  
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'dbo' 
				 AND  TABLE_NAME = 'ContactMetadata'))
BEGIN	
	CREATE TABLE [dbo].[ContactMetadata](
		[Id] [bigint] IDENTITY(1,1) NOT NULL,
		[ExternalGuid] [uniqueidentifier] NOT NULL,
		[ContactId] [bigint] NOT NULL,
		[InvitedBy] [bigint] NULL,
		[InvitedDate] [datetime2](7) NULL,
		[UpdatedAt] [datetime2](7) NULL,
		[CreatedAt] [datetime2](7) NULL,
		[DeletedAt] [datetime2](7) NULL,
	 CONSTRAINT [PK_ContactMetadata] PRIMARY KEY CLUSTERED 
	(
		[Id] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY],
	 CONSTRAINT [UQ_ContactMetadata_ContactId] UNIQUE NONCLUSTERED 
	(
		[ContactId] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	ALTER TABLE [dbo].[ContactMetadata]  WITH CHECK ADD  CONSTRAINT [FK_ContactMetadata_Contacts] FOREIGN KEY([ContactId])
	REFERENCES [dbo].[Contacts] ([Id])


	ALTER TABLE [dbo].[ContactMetadata] CHECK CONSTRAINT [FK_ContactMetadata_Contacts]


	ALTER TABLE [dbo].[ContactMetadata]  WITH CHECK ADD  CONSTRAINT [FK_ContactMetadata_Contacts_InvitedBy] FOREIGN KEY([InvitedBy])
	REFERENCES [dbo].[Contacts] ([Id])


	ALTER TABLE [dbo].[ContactMetadata] CHECK CONSTRAINT [FK_ContactMetadata_Contacts_InvitedBy]

END

/* 
	END Create [dbo].[ContactMetadata] 
*/

/***************
	 END of Release Changeset for Gushers
***************/





/***************
	 Release Changeset for Peeps
***************/


/*
	add DeclineComment - comments inputted by user when it has decline loan status
*/

IF COL_LENGTH('Loans', 'DeclineComment') IS NULL
    BEGIN
        ALTER TABLE Loans ADD DeclineComment NVARCHAR(500) NULL;
END
GO
/* END add DeclineComment - comments inputted by user when it has decline loan status */


/*
	add SortOrder for LoanStatuses ordering of status
*/

IF COL_LENGTH('LoanStatuses', 'SortOrder') IS NULL
    BEGIN
        ALTER TABLE LoanStatuses ADD SortOrder tinyint NULL;
END
GO
/* END add SortOrder for LoanStatuses ordering of status */


/*
	UPDATE LOAN STATUS EXTERNALGUID TO AUTO and ADD SortOrder
*/
DECLARE @externalguid_newlead NVARCHAR(150) = N'00000000-0000-0000-0000-000000000001';
IF EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanStatuses] WHERE [ExternalGuid]=@externalguid_newlead)
	BEGIN
		UPDATE [dbo].[LoanStatuses]
		SET
			[ExternalGuid] = NEWID()
			,[SortOrder] = 1
		WHERE [ExternalGuid] = CONVERT(uniqueidentifier,@externalguid_newlead)
	END
GO


DECLARE @externalguid_newdeal NVARCHAR(150) = N'00000000-0000-0000-0000-000000000010';
IF EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanStatuses] WHERE [ExternalGuid]=@externalguid_newdeal)
	BEGIN
		UPDATE [dbo].[LoanStatuses]
		SET
			[ExternalGuid] = NEWID()
			,[SortOrder] = 2
		WHERE [ExternalGuid] = CONVERT(uniqueidentifier,@externalguid_newdeal)
	END
GO

DECLARE @externalguid_signedup NVARCHAR(150) = N'00000000-0000-0000-0000-000000000100';
IF EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanStatuses] WHERE [ExternalGuid]=@externalguid_signedup)
	BEGIN
		UPDATE [dbo].[LoanStatuses]
		SET
			[ExternalGuid] = NEWID()
			,[SortOrder] = 3
		WHERE [ExternalGuid] = CONVERT(uniqueidentifier,@externalguid_signedup)
	END
GO


DECLARE @externalguid_closed NVARCHAR(150) = N'00000000-0000-0000-0000-000000001000';
IF EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanStatuses] WHERE [ExternalGuid]=@externalguid_closed)
	BEGIN
		UPDATE [dbo].[LoanStatuses]
		SET
			[ExternalGuid] = NEWID()
			,[SortOrder] = 4
		WHERE [ExternalGuid] = CONVERT(uniqueidentifier,@externalguid_closed)
	END
GO

DECLARE @externalguid_dead NVARCHAR(150) = N'00000000-0000-0000-0000-000000010000';
IF EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanStatuses] WHERE [ExternalGuid]=@externalguid_dead)
	BEGIN
		UPDATE [dbo].[LoanStatuses]
		SET
			[ExternalGuid] = NEWID()
			,[SortOrder] = 6
		WHERE [ExternalGuid] = CONVERT(uniqueidentifier,@externalguid_dead)
	END
GO


/* END UPDATE LOAN STATUS EXTERNALGUID TO AUTO and ADD SortOrder */


/*
	ADD DECLINED STATUS
*/
DECLARE @LOANSTATUS_DECLINED NVARCHAR(150) = 'Declined';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanStatuses] WHERE [Display]=@LOANSTATUS_DECLINED)
BEGIN
	INSERT INTO[dbo].[LoanStatuses]([ExternalGuid], [Display], [Value], [SortOrder])
	VALUES(NEWID(), @LOANSTATUS_DECLINED, 'declined', 5);
END
GO
/* ENDADD DECLINED STATUS */


/*
	Add LastLogin as datetime2(7) NULL in ContactMetadata
*/

IF COL_LENGTH('ContactMetadata', 'LastLogin') IS NULL
    BEGIN
        ALTER TABLE dbo.ContactMetadata ADD LastLogin datetime2(7) NULL;
END
GO

/*
	END: Add LastLogin as datetime2(7) NULL in ContactMetadata
*/

/*
	Remove InvitedBy and Add InvitedByUser as NVARCHAR(128) NULL in ContactMetadata
*/

IF COL_LENGTH('ContactMetadata', 'InvitedByUser') IS NULL
BEGIN	
	/* Using 128 as the limit defined in cognito username*/
	ALTER TABLE ContactMetadata ADD InvitedByUser NVARCHAR(128) NULL;

END

GO

IF COL_LENGTH('ContactMetadata', 'InvitedBy') IS NOT NULL
BEGIN
	ALTER TABLE [dbo].[ContactMetadata] DROP CONSTRAINT [FK_ContactMetadata_Contacts_InvitedBy]

	ALTER TABLE ContactMetadata
	DROP COLUMN InvitedBy;
END

GO

/*
	END: Remove InvitedBy and Add InvitedByUser as NVARCHAR(128) NULL in ContactMetadata
*/


/*
	Add SignedUpDate as datetime2(7) NULL NULL in ContactMetadata
*/

IF COL_LENGTH('ContactMetadata', 'SignedUpDate') IS NULL
BEGIN		
	ALTER TABLE ContactMetadata ADD SignedUpDate datetime2(7) NULL;
END

GO

/*
	END: Add SignedUpDate as datetime2(7) NULL NULL in ContactMetadata
*/


/***************
	 END of Release Changeset for Peeps
***************/



/***************
	 Release Changeset for Whoppers
***************/

/*
 	Start : DP-736 - Value displayed in the Created By field is not the user who created the checklist ...
*/

 -- create a new colum CreatedBy
IF NOT EXISTS (
	SELECT TOP 1 1 
	FROM sys.columns col
	INNER JOIN sys.tables tbl
	ON col.object_id = tbl.object_id
	WHERE LOWER(tbl.name) = 'quickselectlists'
	AND LOWER(col.name) = 'createdby'
)
 BEGIN
	ALTER TABLE dbo.QuickSelectLists
	ADD CreatedBy NVARCHAR(128) NULL
 END
 
 GO
 /*
 	End : DP-736 
 */


 /*
 	Start : DP-597 - ADD column for person who upload files in document request ...
*/
  
 -- create a new colum UploadedBy
IF NOT EXISTS (
	SELECT TOP 1 1 
	FROM sys.columns col
	INNER JOIN sys.tables tbl
	ON col.object_id = tbl.object_id
	WHERE LOWER(tbl.name) = 'UploadedDocuments'
	AND LOWER(col.name) = 'uploadedby'
)
 BEGIN
	ALTER TABLE dbo.UploadedDocuments
	ADD UploadedBy NVARCHAR(128) NULL
 END
 
 GO
 /*
 	End : DP-597 
 */

/***************
	 END of Release Changeset for Whoppers
***************/



/***************
	 Release Changeset for Cloud9
***************/

/*
 	Start : DP-724 - ALTER COLUMN FOR COMMENTS TABLE
*/

IF NOT EXISTS (
	SELECT TOP 1
	1
FROM sys.columns col
	INNER JOIN sys.tables tbl
	ON col.object_id = tbl.object_id
WHERE LOWER(tbl.name) = 'Comments'
	AND LOWER(col.name) = 'LoanId'
)
BEGIN
	ALTER TABLE dbo.Comments
	ADD LoanId BIGINT NULL

	ALTER TABLE [dbo].[Comments]  WITH CHECK ADD  CONSTRAINT [FK_Comments_Loans] FOREIGN KEY([LoanId])
	REFERENCES [dbo].[Loans] ([Id])
END
GO

IF COL_LENGTH('[dbo].[Comments]', 'RequestedDocumentId') IS NOT NULL
BEGIN
	ALTER TABLE [dbo].[Comments] 
	DROP CONSTRAINT [FK_Comments_RequestedDocuments], COLUMN [RequestedDocumentId]
END
GO

IF COL_LENGTH('[dbo].[Loans]', 'DeclineComment') IS NOT NULL
BEGIN
	ALTER TABLE [dbo].Loans 
	DROP COLUMN DeclineComment
END
GO

IF (SELECT is_identity
	FROM sys.columns
	WHERE [object_id] = object_id('Comments') and [name]='Id') = 0
BEGIN
	ALTER TABLE dbo.Comments DROP  CONSTRAINT PK_Comments, COLUMN Id
	ALTER TABLE dbo.Comments 
			ADD Id BIGINT IDENTITY(1,1)
			CONSTRAINT PK_Comments PRIMARY KEY CLUSTERED
END
GO

IF EXISTS (
	SELECT TOP 1 1
	FROM sys.columns col
		INNER JOIN sys.tables tbl
		ON col.object_id = tbl.object_id
	WHERE tbl.name = 'Comments'
		AND col.name = 'CommenterId'
)
BEGIN

	ALTER TABLE dbo.Comments DROP COLUMN CommenterId

END
GO

IF NOT EXISTS (
	SELECT TOP 1 1
	FROM sys.columns col
		INNER JOIN sys.tables tbl
		ON col.object_id = tbl.object_id
	WHERE tbl.name = 'Comments'
	AND col.name = 'CommentedBy'
)
 BEGIN

	ALTER TABLE dbo.Comments ADD CommentedBy [nvarchar](128)
END
GO
/*
    END : DP-724
*/

/***************
	 END of Release Changeset for Cloud9
***************/






/***************
	 Release Changeset for Smarties
***************/

/*START DP-789: Add question for Multifamily property selection*/

IF NOT EXISTS(SELECT TOP 1 1 FROM sys.columns WHERE object_id = OBJECT_ID('dbo.Loans') and name='MultiFamilyUnitRange')
BEGIN
	ALTER TABLE dbo.Loans
	ADD MultiFamilyUnitRange varchar(10) NULL
END

GO
/*END DP-789: Add question for Multifamily property selection: Number of Units. Possible values: 5to10,10to20*/

/***************
	 END of Release Changeset for Smarties
***************/








/***************
	 Release Changeset for Smarties HotFix
***************/

/****** Object:  Table [dbo].[ProspectInformation]    Script Date: 2018-05-20 14:32:15.387 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

IF (NOT EXISTS (SELECT TOP 1 1 
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'dbo' 
                 AND  TABLE_NAME = 'ProspectInformation'))
BEGIN

	CREATE TABLE [dbo].[ProspectInformation](
		[Id] [bigint] IDENTITY(1,1) NOT NULL,
		[ExternalGuid] [uniqueidentifier] NOT NULL,
		[FullName] nvarchar(150) NOT NULL,
		[Email] nvarchar(150) NOT NULL,
		[PlannedPurhaseDate] [datetime2](7) NULL,
		[UpdatedAt] [datetime2](7) NULL,
		[CreatedAt] [datetime2](7) NULL,
		[DeletedAt] [datetime2](7) NULL
	 CONSTRAINT [PK_ProspectInformation] PRIMARY KEY CLUSTERED 
	(
		[Id] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

END

GO

/***************
	 END of Release Changeset for Smarties  HotFix
***************/





/***************
	 Release Changeset for Lifesavers 
***************/

/*START DP-835 [DP] Display originator info in All Loans*/
USE [DocumentDb]

IF NOT EXISTS(SELECT TOP 1 1 FROM sys.columns WHERE object_id = OBJECT_ID('dbo.Loans') and name='Originator')
BEGIN
	ALTER TABLE dbo.Loans
	ADD Originator nvarchar(150) NULL
END

GO
/*END DP-835 [DP] Display originator info in All Loans*/

/***************
	 END of Release Changeset for Lifesavers
***************/





/***************
	 Release Changeset for Warheads 
***************/


/*DP-732: As a CRE, I want to request documents from a contact. 
DocumentRequests table will be connected to two tables: ContactDocumentRequests and LoanDocumentRequests.
Each table will have DocumentRequestID referring to DocumentRequests table.
ContactDocumentRequests will be used to retrieve all document requests from a contact.
*/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

IF (NOT EXISTS (SELECT TOP 1 1
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'dbo' 
                 AND  TABLE_NAME = 'LoanDocumentRequests'))
BEGIN
    CREATE TABLE [dbo].LoanDocumentRequests(
		[Id] [bigint] IDENTITY(1,1) NOT NULL,
		[ExternalGuid] [uniqueidentifier] NOT NULL,
		[LoanId] [bigint] NOT NULL,
		[DocumentRequestId] [bigint] NOT NULL,
		[UpdatedAt] [datetime2](7) NULL,
		[CreatedAt] [datetime2](7) NULL,
		[DeletedAt] [datetime2](7) NULL,
	 CONSTRAINT [PK_LoanDocumentRequests] PRIMARY KEY CLUSTERED 
	(
		[Id] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	ALTER TABLE [dbo].[LoanDocumentRequests] ADD  CONSTRAINT [DF_LoanDocumentRequests_ExternalGuid]  DEFAULT (newid()) FOR [ExternalGuid]

	ALTER TABLE [dbo].[LoanDocumentRequests] ADD  CONSTRAINT [DF_LoanDocumentRequests_CreatedAt]  DEFAULT (getdate()) FOR [CreatedAt]

	ALTER TABLE [dbo].[LoanDocumentRequests] ADD  CONSTRAINT [DF_LoanDocumentRequests_UpdatedAt]  DEFAULT (getdate()) FOR [UpdatedAt]

	ALTER TABLE [dbo].[LoanDocumentRequests]
		ADD CONSTRAINT UQ_LoanDocumentRequests_Loans_DocumentRequests UNIQUE (LoanId, DocumentRequestId); 

	ALTER TABLE [dbo].[LoanDocumentRequests]  WITH CHECK ADD  CONSTRAINT [FK_LoanDocumentRequests_Loans] FOREIGN KEY([LoanId])
	REFERENCES [dbo].[Loans] ([Id])

	ALTER TABLE [dbo].[LoanDocumentRequests] CHECK CONSTRAINT [FK_LoanDocumentRequests_Loans]

	ALTER TABLE [dbo].[LoanDocumentRequests]  WITH CHECK ADD  CONSTRAINT [FK_LoanDocumentRequests_DocumentRequests] FOREIGN KEY([DocumentRequestId])
	REFERENCES [dbo].[DocumentRequests] ([Id])

	ALTER TABLE [dbo].[LoanDocumentRequests] CHECK CONSTRAINT [FK_LoanDocumentRequests_DocumentRequests]

	ALTER TABLE [dbo].[LoanDocumentRequests]
		ADD CONSTRAINT UQ_LoanDocumentRequests_ExternalGuid UNIQUE (ExternalGuid); 

END

GO

IF (NOT EXISTS (SELECT TOP 1 1
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'dbo' 
                 AND  TABLE_NAME = 'ContactDocumentRequests'))
BEGIN

	CREATE TABLE [dbo].ContactDocumentRequests(
		[Id] [bigint] IDENTITY(1,1) NOT NULL,
		[ExternalGuid] [uniqueidentifier] NOT NULL,
		[ContactId] [bigint] NOT NULL,
		[DocumentRequestId] [bigint] NOT NULL,
		[UpdatedAt] [datetime2](7) NULL,
		[CreatedAt] [datetime2](7) NULL,
		[DeletedAt] [datetime2](7) NULL,
	 CONSTRAINT [PK_ContactDocumentRequests] PRIMARY KEY CLUSTERED 
	(
		[Id] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]


	ALTER TABLE [dbo].[ContactDocumentRequests] ADD  CONSTRAINT [DF_ContactDocumentRequests_ExternalGuid]  DEFAULT (newid()) FOR [ExternalGuid]

	ALTER TABLE [dbo].[ContactDocumentRequests] ADD  CONSTRAINT [DF_ContactDocumentRequests_CreatedAt]  DEFAULT (getdate()) FOR [CreatedAt]

	ALTER TABLE [dbo].[ContactDocumentRequests] ADD  CONSTRAINT [DF_ContactDocumentRequests_UpdatedAt]  DEFAULT (getdate()) FOR [UpdatedAt]

	ALTER TABLE [dbo].[ContactDocumentRequests]
		ADD CONSTRAINT UQ_ContactDocumentRequests_ExternalGuid UNIQUE (ExternalGuid); 

	ALTER TABLE [dbo].[ContactDocumentRequests]
		ADD CONSTRAINT UQ_ContactDocumentRequests_Contacts_DocumentRequests UNIQUE (ContactId, DocumentRequestId); 

	ALTER TABLE [dbo].[ContactDocumentRequests]  WITH CHECK ADD  CONSTRAINT [FK_ContactDocumentRequests_Contacts] FOREIGN KEY([ContactId])
	REFERENCES [dbo].[Contacts] ([Id])

	ALTER TABLE [dbo].[ContactDocumentRequests] CHECK CONSTRAINT [FK_ContactDocumentRequests_Contacts]

	ALTER TABLE [dbo].[ContactDocumentRequests]  WITH CHECK ADD  CONSTRAINT [FK_ContactDocumentRequests_DocumentRequests] FOREIGN KEY([DocumentRequestId])
	REFERENCES [dbo].[DocumentRequests] ([Id])
	
	ALTER TABLE [dbo].[ContactDocumentRequests] CHECK CONSTRAINT [FK_ContactDocumentRequests_DocumentRequests]
	
END

GO

/***************
	 END of Release Changeset for Warheads 
***************/



/***************
	 Release Changeset for Nerds 
***************/


/*DP-882 [DP] Create database table for Originator to store Originator's Name and Email.
This ticket related to (DP-850 [DP] Email updates should only go to the assigned loan originator).
*/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

IF (NOT EXISTS (SELECT TOP 1 1
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'dbo' 
                 AND  TABLE_NAME = 'LoanOriginators'))
BEGIN
    CREATE TABLE [dbo].[LoanOriginators](
	[Id] [bigint] IDENTITY(1,1) NOT NULL,
	[ExternalGuid] [uniqueidentifier] NOT NULL CONSTRAINT [DF_LoanOriginators_ExternalGuid]  DEFAULT (newid()),
	[Firstname] [nvarchar](50) NOT NULL,
	[Lastname] [nvarchar](50) NOT NULL,
	[PrimaryEmail] [nvarchar](128) NOT NULL,
	[UpdatedAt] [datetime2](7) NULL CONSTRAINT [DF_LoanOriginators_UpdatedAt]  DEFAULT (getdate()),
	[CreatedAt] [datetime2](7) NULL CONSTRAINT [DF_LoanOriginators_CreatedAt]  DEFAULT (getdate()),
	[DeletedAt] [datetime2](7) NULL,
	 CONSTRAINT [PK_LoanOriginators] PRIMARY KEY CLUSTERED 
	(
		[Id] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY],
	 CONSTRAINT [UQ_LoanOriginators_ExternalGuid] UNIQUE NONCLUSTERED 
	(
		[ExternalGuid] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY],
	 CONSTRAINT [UQ_LoanOriginators_PrimaryEmail] UNIQUE NONCLUSTERED 
	(
		[PrimaryEmail] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

END

GO


/*
	Add Loan Originators:
		Jason Petri --> jason.petri@plumlending.com
        Kris Boudreau -->kris.boudreau@plumlending.com
        Mark Stevens --> mark.stevens@plumlending.com
        Megan McElgunn --> megan.mcelgunn@plumlending.com
        Robert Gabaldon --> robert.gabaldon@plumlending.com
        Torsten Galley --> torsten@plumlending.com
*/

DECLARE @FIRSTNAME NVARCHAR(150) = 'Jason';
DECLARE @LASTNAME NVARCHAR(150) = 'Petri';
DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'jason.petri@plumlending.com';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
BEGIN
	INSERT INTO[dbo].[LoanOriginators]([Firstname], [Lastname], [PrimaryEmail])
	VALUES(@FIRSTNAME, @LASTNAME, @PRIMARY_EMAIL);
END
GO

DECLARE @FIRSTNAME NVARCHAR(150) = 'Kris';
DECLARE @LASTNAME NVARCHAR(150) = 'Boudreau';
DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'kris.boudreau@plumlending.com';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
BEGIN
	INSERT INTO[dbo].[LoanOriginators]([Firstname], [Lastname], [PrimaryEmail])
	VALUES(@FIRSTNAME, @LASTNAME, @PRIMARY_EMAIL);
END
GO

DECLARE @FIRSTNAME NVARCHAR(150) = 'Mark';
DECLARE @LASTNAME NVARCHAR(150) = 'Stevens';
DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'mark.stevens@plumlending.com';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
BEGIN
	INSERT INTO[dbo].[LoanOriginators]([Firstname], [Lastname], [PrimaryEmail])
	VALUES(@FIRSTNAME, @LASTNAME, @PRIMARY_EMAIL);
END
GO

DECLARE @FIRSTNAME NVARCHAR(150) = 'Megan';
DECLARE @LASTNAME NVARCHAR(150) = 'McElgunn';
DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'megan.mcelgunn@plumlending.com';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
BEGIN
	INSERT INTO[dbo].[LoanOriginators]([Firstname], [Lastname], [PrimaryEmail])
	VALUES(@FIRSTNAME, @LASTNAME, @PRIMARY_EMAIL);
END
GO

DECLARE @FIRSTNAME NVARCHAR(150) = 'Robert';
DECLARE @LASTNAME NVARCHAR(150) = 'Gabaldon';
DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'robert.gabaldon@plumlending.com';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
BEGIN
	INSERT INTO[dbo].[LoanOriginators]([Firstname], [Lastname], [PrimaryEmail])
	VALUES(@FIRSTNAME, @LASTNAME, @PRIMARY_EMAIL);
END
GO

DECLARE @FIRSTNAME NVARCHAR(150) = 'Torsten';
DECLARE @LASTNAME NVARCHAR(150) = 'Galley';
DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'torsten@plumlending.com';
IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
BEGIN
	INSERT INTO[dbo].[LoanOriginators]([Firstname], [Lastname], [PrimaryEmail])
	VALUES(@FIRSTNAME, @LASTNAME, @PRIMARY_EMAIL);
END
GO

/*
    END OF ADDING LOAN ORIGINATORS 
*/

/*END DP-882 */

/* DP-905: Loans are duplicated. */

DELETE 
FROM [LoanStatuses] 
WHERE 
	Id NOT IN (
		SELECT MIN(Id) AS Id 
		FROM [LoanStatuses] 
		GROUP BY [Value]
		);

GO

/* END DP-905: Loans are duplicated. */

/***************
	 END of Release Changeset for Nerds 
***************/


/***************
	 Release Changeset for KitKat 
***************/


/*DP-732: As a CRE, I want to request documents from a contact. 
DocumentRequests table will be connected to two tables: ContactDocumentRequests and LoanDocumentRequests.
Each table will have DocumentRequestID referring to DocumentRequests table.
LoanID is not required anymore in inserting at DocumentRequests. 
Instead, additional entry should be made at LoanDocumentRequests which is to follow.
*/

IF EXISTS
(
	SELECT TOP 1 1 
	FROM sys.columns 
	WHERE object_id = OBJECT_ID('dbo.DocumentRequests')
	and name='LoanId'
)
BEGIN
ALTER TABLE dbo.DocumentRequests ALTER COLUMN LoanId bigint NULL;
END
GO

IF EXISTS 
	(
		SELECT *
		FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
		WHERE CONSTRAINT_NAME='FK_DocumentRequests_Loans'
	)
BEGIN
ALTER TABLE dbo.DocumentRequests DROP CONSTRAINT FK_DocumentRequests_Loans;
END
GO

/*End of DP 732*/

/***************
	 END of Release Changeset for KitKat 
***************/




/***************
	 Release Changeset for SweetTarts 
***************/


/*
	Start: DP-943
	Loan statuses should mirror the stages in Salesforce. This will help make integration more seamless when we begin to integrate the portal with SFDC in the future.

	Improvement:

	Statuses should be in the following order:
	New Lead
	Financials Requested
	Sizing
	Sent for Quote
	Term Sheet Issued
	Term Sheet Signed
	Application Issued
	Application Signed
	Committee Approved
	Closed
	On-Hold
	Dead
	All
	Tester Notes:
	Ensure that the following statuses are no longer available to select:
	New Deal
	Signed Up
	Declined

	Ensure loans previously marked New Deal are mapped to Financials Requested
	Ensure loans previously marked Signed Up are mapped to Application Signed
	Ensure loans previously marked Declined are mapped to Dead
*/

--Step 1. Insert new statuses
	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'newlead'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'New Lead', 'newlead', GETDATE(), GETDATE(), 1)

	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'financialsrequested'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Financials Requested', 'financialsrequested', GETDATE(), GETDATE(), 2)

	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'sizing'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Sizing', 'sizing', GETDATE(), GETDATE(), 3)

	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'sentforquote'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Sent for Quote', 'sentforquote', GETDATE(), GETDATE(), 4)

	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'termsheetissued'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Term Sheet Issued', 'termsheetissued', GETDATE(), GETDATE(), 5)


	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'termsheetsigned'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Term Sheet Signed', 'termsheetsigned', GETDATE(), GETDATE(), 6)


	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'applicationissued'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Application Issued', 'applicationissued', GETDATE(), GETDATE(), 7)


	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'applicationsigned'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Application Signed', 'applicationsigned', GETDATE(), GETDATE(), 8)


	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'committeeapproved'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Committee Approved', 'committeeapproved', GETDATE(), GETDATE(), 9)


	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'closed'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Closed', 'closed', GETDATE(), GETDATE(), 10)


	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'onhold'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'On-Hold', 'onhold', GETDATE(), GETDATE(), 11)


	IF NOT EXISTS (	SELECT TOP 1 1 
					FROM dbo.LoanStatuses
					WHERE Value = 'dead'
	)
	INSERT INTO dbo.LoanStatuses(ExternalGuid, Display, Value, CreatedAt, UpdatedAt, SortOrder)
	VALUES (NEWID(), 'Dead', 'dead', GETDATE(), GETDATE(), 12)

--Step 2. Update New Loan Mappings for New Deal, Signed Up, Declined

	--update existing loans with status = newdeal to financialsrequested
	IF EXISTS	(	SELECT TOP 1 1 
					FROM dbo.Loans
					WHERE Status = 'newdeal'
	)
	UPDATE dbo.Loans
	SET Status = 'financialsrequested'
	WHERE Status = 'newdeal'

	--update existing loans with status = signedup to applicationsigned
	IF EXISTS	(	SELECT TOP 1 1 
					FROM dbo.Loans
					WHERE Status = 'signedup'
	)
	UPDATE dbo.Loans
	SET Status = 'applicationsigned'
	WHERE Status = 'signedup' 

	--update existing loans with status = declined to dead
	IF EXISTS	(	SELECT TOP 1 1 
					FROM dbo.Loans
					WHERE Status = 'declined'
	)
	UPDATE dbo.Loans
	SET Status = 'dead'
	WHERE Status = 'declined' 

--Step 3. Soft delete New Deal, Signed Up &  Declined statuses
	UPDATE dbo.LoanStatuses
	SET DeletedAt = GETDATE()
	WHERE Value IN ('newdeal','signedup','declined')

--Step 4. Update Sort Orders 

	--for Closed and Dead Statuses
	UPDATE dbo.LoanStatuses
	SET SortOrder = 10
	WHERE Value = 'closed'

	UPDATE dbo.LoanStatuses
	SET SortOrder = 12
	WHERE Value = 'dead'

	--for soft-deleted statuse, set sort statuses to NULL
	UPDATE dbo.LoanStatuses
	SET SortOrder = NULL
	WHERE DeletedAt IS NOT NULL

/*
	End: DP-943
*/

GO

/***************
	 END of Release Changeset for SweetTarts 
***************/



/***************
     Release Changeset for Milk Duds 
***************/

/*
    Start: DP-949 [DP] Add Bruce Neel, Christopher Blais and Mike Trehey to Originator filter
*/

    DECLARE @FIRSTNAME NVARCHAR(150) = 'Bruce';
    DECLARE @LASTNAME NVARCHAR(150) = 'Neel';
    DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'bruce.neel@plumlending.com';
    IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
    BEGIN
        INSERT INTO[dbo].[LoanOriginators]([Firstname], [Lastname], [PrimaryEmail])
        VALUES(@FIRSTNAME, @LASTNAME, @PRIMARY_EMAIL);
    END
    GO

    DECLARE @FIRSTNAME NVARCHAR(150) = 'Christopher';
    DECLARE @LASTNAME NVARCHAR(150) = 'Blais';
    DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'christopher.blais@plumlending.com';
    IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
    BEGIN
        INSERT INTO[dbo].[LoanOriginators]([Firstname], [Lastname], [PrimaryEmail])
        VALUES(@FIRSTNAME, @LASTNAME, @PRIMARY_EMAIL);
    END
    GO

    DECLARE @FIRSTNAME NVARCHAR(150) = 'Mike';
    DECLARE @LASTNAME NVARCHAR(150) = 'Trehey';
    DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'mike.trehey@plumlending.com';
    IF NOT EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
    BEGIN
        INSERT INTO[dbo].[LoanOriginators]([Firstname], [Lastname], [PrimaryEmail])
        VALUES(@FIRSTNAME, @LASTNAME, @PRIMARY_EMAIL);
    END
    GO
/*
    End: DP-949 [DP] Add Bruce Neel, Christopher Blais and Mike Trehey to Originator filter

*/


/*
    Start: DP-947 [DP] Remove Megan McElgunn and Robert Gabaldon under Originator filter
*/

    DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'megan.mcelgunn@plumlending.com';
    IF EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
    BEGIN
        DELETE FROM [dbo].[LoanOriginators] WHERE PrimaryEmail =  @PRIMARY_EMAIL;
    END
    GO

    DECLARE @PRIMARY_EMAIL NVARCHAR(150) = 'robert.gabaldon@plumlending.com';
    IF EXISTS (SELECT TOP 1 1 FROM[dbo].[LoanOriginators] WHERE [PrimaryEmail]=@PRIMARY_EMAIL)
    BEGIN
        DELETE FROM [dbo].[LoanOriginators] WHERE PrimaryEmail =  @PRIMARY_EMAIL;
    END
    GO

/*
    End: DP-947 [DP] Remove Megan McElgunn and Robert Gabaldon under Originator filter
*/

/*
    Start: DP-981 [DP] Update loan data (table) with the new loan originator value.
*/

    DECLARE @OLD_ORIGINATOR_VALUE NVARCHAR(150) = 'jasonpetri';
    DECLARE @NEW_ORIGINATOR_VALUE NVARCHAR(150) = 'jason.petri@plumlending.com';
    IF EXISTS (SELECT TOP 1 1 FROM[dbo].[Loans] WHERE [Originator]=@OLD_ORIGINATOR_VALUE)
    BEGIN
        UPDATE [dbo].[Loans] SET [Originator]=@NEW_ORIGINATOR_VALUE WHERE [Originator] =  @OLD_ORIGINATOR_VALUE;
    END
    GO

    DECLARE @OLD_ORIGINATOR_VALUE NVARCHAR(150) = 'krisboudreau';
    DECLARE @NEW_ORIGINATOR_VALUE NVARCHAR(150) = 'kris.boudreau@plumlending.com';
    IF EXISTS (SELECT TOP 1 1 FROM[dbo].[Loans] WHERE [Originator]=@OLD_ORIGINATOR_VALUE)
    BEGIN
        UPDATE [dbo].[Loans] SET [Originator]=@NEW_ORIGINATOR_VALUE WHERE [Originator] =  @OLD_ORIGINATOR_VALUE;
    END
    GO

    DECLARE @OLD_ORIGINATOR_VALUE NVARCHAR(150) = 'markstevens';
    DECLARE @NEW_ORIGINATOR_VALUE NVARCHAR(150) = 'mark.stevens@plumlending.com';
    IF EXISTS (SELECT TOP 1 1 FROM[dbo].[Loans] WHERE [Originator]=@OLD_ORIGINATOR_VALUE)
    BEGIN
        UPDATE [dbo].[Loans] SET [Originator]=@NEW_ORIGINATOR_VALUE WHERE [Originator] =  @OLD_ORIGINATOR_VALUE;
    END
    GO

    DECLARE @OLD_ORIGINATOR_VALUE NVARCHAR(150) = 'torstengalley';
    DECLARE @NEW_ORIGINATOR_VALUE NVARCHAR(150) = 'torsten@plumlending.com';
    IF EXISTS (SELECT TOP 1 1 FROM[dbo].[Loans] WHERE [Originator]=@OLD_ORIGINATOR_VALUE)
    BEGIN
        UPDATE [dbo].[Loans] SET [Originator]=@NEW_ORIGINATOR_VALUE WHERE [Originator] =  @OLD_ORIGINATOR_VALUE;
    END
    GO

    DECLARE @OLD_ORIGINATOR_VALUE NVARCHAR(150) = 'bruceneel';
    DECLARE @NEW_ORIGINATOR_VALUE NVARCHAR(150) = 'bruce.neel@plumlending.com';
    IF EXISTS (SELECT TOP 1 1 FROM[dbo].[Loans] WHERE [Originator]=@OLD_ORIGINATOR_VALUE)
    BEGIN
        UPDATE [dbo].[Loans] SET [Originator]=@NEW_ORIGINATOR_VALUE WHERE [Originator] =  @OLD_ORIGINATOR_VALUE;
    END
    GO

    DECLARE @OLD_ORIGINATOR_VALUE NVARCHAR(150) = 'christopherblais';
    DECLARE @NEW_ORIGINATOR_VALUE NVARCHAR(150) = 'christopher.blais@plumlending.com';
    IF EXISTS (SELECT TOP 1 1 FROM[dbo].[Loans] WHERE [Originator]=@OLD_ORIGINATOR_VALUE)
    BEGIN
        UPDATE [dbo].[Loans] SET [Originator]=@NEW_ORIGINATOR_VALUE WHERE [Originator] =  @OLD_ORIGINATOR_VALUE;
    END
    GO

    DECLARE @OLD_ORIGINATOR_VALUE NVARCHAR(150) = 'miketrehey';
    DECLARE @NEW_ORIGINATOR_VALUE NVARCHAR(150) = 'mike.trehey@plumlending.com';
    IF EXISTS (SELECT TOP 1 1 FROM[dbo].[Loans] WHERE [Originator]=@OLD_ORIGINATOR_VALUE)
    BEGIN
        UPDATE [dbo].[Loans] SET [Originator]=@NEW_ORIGINATOR_VALUE WHERE [Originator] =  @OLD_ORIGINATOR_VALUE;
    END
    GO


/*
    End: DP-981 [DP] Update loan data (table) with the new loan originator value.
*/

/***************
     END of Release Changeset for Milk Duds 
***************/



