const ModelAssociation = (() => {

    build = (model) => {
        //This association allows us to include property details along with the loan
        model.Loans.belongsTo(model.PropertyDetails, { foreignKey: "propertyDetailId", targetKey: "id" });

        model.Loans.belongsTo(model.LoanStatuses, { foreignKey: "status", targetKey: "value" });


        //This association will create an array of borrowers on the loans object
        model.Loans.hasMany(model.Borrowers);
        //this association will allow borrower to get the contact information
        model.Borrowers.belongsTo(model.Contacts, { foreignKey: "contactId", targetKey: "id" });

        //This association allows us to include document requests along with the loan
        model.Loans.hasMany(model.DocumentRequests);
        model.DocumentRequests.belongsTo(model.Loans, { foreignKey: "loanId", targetKey: "id" });
        
        //This association allows us to include contact requests along with the contact
        model.Contacts.hasMany(model.ContactDocumentRequests);
        model.ContactDocumentRequests.belongsTo(model.Contacts, { foreignKey: "contactId", targetKey: "id" });

        //This association allows us to include contact requests type along with the general document requests
        model.DocumentRequests.hasMany(model.ContactDocumentRequests);
        model.ContactDocumentRequests.belongsTo(model.DocumentRequests, { foreignKey: "documentRequestId", targetKey: "id" });

        //This association will create an array of requesteddocuments on the documentrequest objects
        model.DocumentRequests.hasMany(model.RequestedDocuments);
        model.RequestedDocuments.belongsTo(model.DocumentRequests);
        
        //This association will allow us to pull the checklist information on the requesteddocument
        model.RequestedDocuments.belongsTo(model.Checklist, { foreignKey: "checklistId", targetKey: "id" })

        //This association will allow us to pull the checklist information on the requesteddocument
        model.Checklist.belongsTo(model.DocumentCategories, { foreignKey: "documentCategoryId", targetKey: "id" })

        //This association will allow us to have an array of quick select documents in quickselect list
        model.QuickSelectLists.hasMany(model.QuickSelectDocuments, { foreignKey: "quickSelectId", targetKey: "id" });
        model.QuickSelectDocuments.belongsTo(model.QuickSelectLists, { foreignKey: "quickSelectId", targetKey: "id" });
        model.QuickSelectDocuments.belongsTo(model.Checklist, { foreignKey: "checklistId", targetKey: "id" });

        //This association will allow us to have an array of uploaded documents in RequestedDocuments
        model.RequestedDocuments.hasMany(model.UploadedDocuments);
        model.UploadedDocuments.belongsTo(model.RequestedDocuments, { foreignKey: "requestedDocumentId", targetKey: "id" });

        model.DefaultQuickSelectList.belongsTo(model.QuickSelectLists, { foreignKey: "quickSelectListId", targetKey: "id" });

        model.ContactMetadata.belongsTo(model.Contacts, { foreignKey: "contactId", targetKey: "id" });
        model.Contacts.hasMany(model.ContactMetadata);
        
        //This association allows us to include Comments along with the loan
        model.Loans.hasMany(model.Comments, { foreignKey: "id", targetKey: "loanId" });

        //This association allows us to include Loan Originators data along with the loan
        model.Loans.belongsTo(model.LoanOriginators, { foreignKey: "originator", targetKey: "primaryEmail" });

        //Recourse association to Lender
        model.Recourses.hasMany(model.Lenders);
        model.Lenders.belongsTo(model.Recourses, { foreignKey: "recourseId", targetKey: "id" });

        //RateLock association to Lender
        model.RateLocks.hasMany(model.Lenders);
        model.Lenders.belongsTo(model.RateLocks, { foreignKey: "rateLockId", targetKey: "id" });

        //LoanOriginators association to Lender
        model.LoanOriginators.hasMany(model.Lenders);
        model.Lenders.belongsTo(model.LoanOriginators, { foreignKey: "loanOriginatorId", targetKey: "id" });
 
        //LenderPropertyTypes association to Lender
        model.Lenders.hasMany(model.LenderPropertyTypes);
        model.LenderPropertyTypes.belongsTo(model.Lenders, { foreignKey: "lenderId", targetKey: "id" });
 
        //LenderPropertyTypes association to PropertyTypes
        model.PropertyTypes.hasMany(model.LenderPropertyTypes);
        model.LenderPropertyTypes.belongsTo(model.PropertyTypes, { foreignKey: "propertyTypeId", targetKey: "id" });

        //LenderPrepaymentPenalties association to Lender
        model.Lenders.hasMany(model.LenderPrepaymentPenalties);
        model.LenderPrepaymentPenalties.belongsTo(model.Lenders, { foreignKey: "lenderId", targetKey: "id" });
 
        //LenderPrepaymentPenalties association to PrepaymentPenalties
        model.PrepaymentPenalties.hasMany(model.LenderPrepaymentPenalties);
        model.LenderPrepaymentPenalties.belongsTo(model.PrepaymentPenalties, { foreignKey: "prepaymentPenaltyId", targetKey: "id" });
  
        //LenderExecutionTypes association to Lender
        model.Lenders.hasMany(model.LenderExecutionTypes);
        model.LenderExecutionTypes.belongsTo(model.Lenders, { foreignKey: "lenderId", targetKey: "id" });
 
        //LenderExecutionTypes association to ExecutionTypes
        model.ExecutionTypes.hasMany(model.LenderExecutionTypes);
        model.LenderExecutionTypes.belongsTo(model.ExecutionTypes, { foreignKey: "executionTypeId", targetKey: "id" });
  
    };

    return {
        build: build
    };

})();

module.exports = ModelAssociation;
