require('dotenv').config();
const fs = require('fs');
const path = require('path');
const { Connection, Request } = require('tedious');
const models = require('./');

const config = {
    client: 'mssql',
    connection: {
        host: process.env.MSSQL_HOST || '127.0.0.1',
        database: process.env.MSSQL_DATABASE || 'DocumentDb',
        user: process.env.MSSQL_USER || 'sa',
        password: process.env.MSSQL_PASSWORD || 'yourStrong(!)Password',
    },
}



beforeAll(async () => {
    jest.setTimeout(50000);
    /*
    temporary solution to keep some existing incorrect model association configurations
    ideally db would be created using models.sequelize.sync({ force: true })
    */
    const dbExists = await query(`
    USE [master]
    select * from sys.databases where name = N'DocumentDb'
    `);

    console.log('DB EXISTS:', dbExists);

    if (!dbExists) {
        console.log('REBUILDING DB');
        await queryFile({
            path: 'databases/master-ddl.sql',
            batchSeparator: 'GO',
        });
        await queryFile({
            path: 'databases/changeset.sql',
            batchSeparator: 'GO',
        });
        await queryFile({
            path: 'databases/release-changeset.sql',
            batchSeparator: 'GO',
        });
    } else {
        console.log('TRUNCATING DB TABLES');
        await queryFile({
            path: 'databases/truncate.sql',
            batchSeparator: 'GO',
        });
    }

    await models(config);
    await models.sequelize.authenticate();
});

afterAll(async () => {
    await models.sequelize.close();
});

function getConnection(config = {}) {
    return new Promise((resolve, reject) => {
        const connection = new Connection({
            userName: config.userName || process.env.MSSQL_USER || 'sa',
            password: config.password || process.env.MSSQL_PASSWORD || 'yourStrong(!)Password',
            server: process.env.MSSQL_HOST || '127.0.0.1',
            database: config.database || 'master',
        });

        connection.on('connect', (error) => {
            if (error) reject(error);
            resolve(connection);
        });
    });
}

async function queryFile(config) {
    const absolutePath = path.join(process.cwd(), config.path);
    const sql = fs.readFileSync(absolutePath, 'utf8');
    if (config.batchSeparator) {
        const queries = sql.split(/\bGO\b/g);
        for(let q of queries) {
            // hack: if not implemented tables will be created in the master db
            const forcedUseQuery = /USE /g.test(q) ? q : `
                USE [DocumentDb]
                ${q}
            `;
            await query(forcedUseQuery, config);
        }
    } else {
        await query(sql);
    }
}
function query(query) {
    return new Promise(async (resolve, reject) => {
        const connection = await getConnection();
        const request = new Request(query, async (error, result) => {
            connection.close();
            if (error) {
                reject(error);
            } else {
                resolve(result);
            }
        });

        connection.execSql(request);
    });
}